<?php
/**
 * Register Custom Post Type Testimonial Card options
 */
add_action('init', 'cep_custom_testimonial_post_type', 1);

if (!function_exists('cep_custom_testimonial_post_type')) {

    function cep_custom_testimonial_post_type() {

        $labels = array(
            'name' => _x('CE Testimonials', 'Post Type General Name', CEPE_DOMAIN),
            'singular_name' => _x('CE Testimonial', 'Post Type Singular Name', CEPE_DOMAIN),
            'menu_name' => __('CE Testimonials', CEPE_DOMAIN),
            'name_admin_bar' => __('CE Testimonial', CEPE_DOMAIN),
            'archives' => __('CE Testimonial Archives', CEPE_DOMAIN),
            'attributes' => __('CE Testimonial Attributes', CEPE_DOMAIN),
            'parent_item_colon' => __('Parent CE Testimonial:', CEPE_DOMAIN),
            'all_items' => __('All CE Testimonials', CEPE_DOMAIN),
            'add_new_item' => __('Add New', CEPE_DOMAIN),
            'add_new' => __('Add New', CEPE_DOMAIN),
            'new_item' => __('New CE Testimonial', CEPE_DOMAIN),
            'edit_item' => __('Edit CE Testimonial', CEPE_DOMAIN),
            'update_item' => __('Update CE Testimonial', CEPE_DOMAIN),
            'view_item' => __('View CE Testimonial', CEPE_DOMAIN),
            'view_items' => __('View CE Testimonials', CEPE_DOMAIN),
            'search_items' => __('Search CE Testimonial', CEPE_DOMAIN),
            'not_found' => __('Not found', CEPE_DOMAIN),
            'not_found_in_trash' => __('Not found in Trash', CEPE_DOMAIN),
            'featured_image' => __('Featured Image', CEPE_DOMAIN),
            'set_featured_image' => __('Set featured image', CEPE_DOMAIN),
            'remove_featured_image' => __('Remove featured image', CEPE_DOMAIN),
            'use_featured_image' => __('Use as featured image', CEPE_DOMAIN),
            'insert_into_item' => __('Insert into CE Testimonial', CEPE_DOMAIN),
            'uploaded_to_this_item' => __('Uploaded to CE Testimonial', CEPE_DOMAIN),
            'items_list' => __('CE Testimonial list', CEPE_DOMAIN),
            'items_list_navigation' => __('CE Testimonial list navigation', CEPE_DOMAIN),
            'filter_items_list' => __('Filter CE Testimonial list', CEPE_DOMAIN),
        );
        $args = array(
            'label' => __('CE Testimonial', CEPE_DOMAIN),
            'description' => __('CE Description', CEPE_DOMAIN),
            'labels' => $labels,
            'supports' => array('title', 'editor', 'thumbnail'),
            'hierarchical' => false,
            'public' => true,
            'show_ui' => true,
            'show_in_menu' => true,
            'menu_position' => 5,
            'menu_icon' => 'dashicons-format-chat',
            'show_in_admin_bar' => true,
            'show_in_nav_menus' => true,
            'can_export' => true,
            'has_archive' => false,
            'exclude_from_search' => false,
            'publicly_queryable' => true,
            'capability_type' => 'post',
        );
        register_post_type('cep_testimonial', $args);
    }

}
add_action('init', 'cep_custom_testimonial_post_type', 0);

/**
 * Add meta box in Testimonial Card options
 */
if (!function_exists('cep_testimonial_meta_box')) {

    function cep_testimonial_meta_box() {
        add_meta_box('testimonial_meta_box', __('Testimonial Information', CEPE_DOMAIN), 'cep_testimonial_create_meta_box', 'cep_testimonial', 'normal', 'high');
    }

}
add_action('add_meta_boxes', 'cep_testimonial_meta_box');

/**
 * Create meta box in Testimonial Card options
 */
if (!function_exists('cep_testimonial_create_meta_box')) {

    function cep_testimonial_create_meta_box($post) {
        $cep_tposition = get_post_meta($post->ID, 'cep_tposition', true);
        $cep_trating = get_post_meta($post->ID, 'cep_trating', true);
        ?>
        <table class="cep-testimonial-inforamtion">
            <tr>
                <th> <label for="cep_tposition"><?php _e('Position', CEPE_DOMAIN) ?></label></th>
                <td><input type="text" class="regular-text" name="cep_tposition" id="cep_tposition" value="<?php echo $cep_tposition; ?>" placeholder="<?php _e('Job title', CEPE_DOMAIN); ?>" /></td>
            </tr>
            <tr>
                <th><label for="cep_trating"><?php _e('Rating', CEPE_DOMAIN) ?></label></th>
                <td><input type="number" name="cep_trating"  min="0" max="5" step="0.1" class="regular-text tooltip-target" id="cep_trating" value="<?php echo $cep_trating; ?>" placeholder="<?php _e('No. of Star', CEPE_DOMAIN); ?>" data-setting="rating" autocomplete="off" /> 
                </td>
            </tr> 
        </table>
        <?php
    }

}

/**
 * Save meta box in Testimonial Card options
 */
if (!function_exists('cep_testimonial_save_meta')) {

    function cep_testimonial_save_meta($post_id) {
        if (isset($_POST["cep_tposition"])) {
            $cep_tposition = $_POST["cep_tposition"];
            update_post_meta($post_id, 'cep_tposition', $cep_tposition);
        }

        if (isset($_POST["cep_trating"])) {
            $cep_trating = $_POST["cep_trating"];
            update_post_meta($post_id, 'cep_trating', $cep_trating);
        }
    }

}
add_action('save_post', 'cep_testimonial_save_meta');

/**
 * Testimonial Card Title List
 */
if (!function_exists('cep_testimonial_title_list')) {

    function cep_testimonial_title_list() {
        global $post;
        $post_args = array(
            'post_type' => 'cep_testimonial',
            'post_status' => 'publish'
        );
        $card_title = get_posts($post_args);
        if (!empty($card_title)) {
            foreach ($card_title as $title) {
                echo $title->post_title;
            }
        }
    }

}

/**
 * Get Post Types List
 */
if (!function_exists('cep_get_post_types')) {

    function cep_get_post_types() {

        $args = array('public' => true, '_builtin' => true);
        $post_types = get_post_types('', 'name');
        $posts = array();
        if ($post_types) {
            foreach ($post_types as $post_type) {
                $posts[$post_type->name] = $post_type->label;
            }
        }

        return $posts;
    }

}