<?php

namespace Elementor;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Image_Size;
use Elementor\Group_Control_Typography;
use Elementor\Widget_Base;
use Elementor\Group_Control_Base;
use ElementorPro\Classes\Utils;
use ElementorPro\Modules\QueryControl\Module;

if (!defined('ABSPATH'))
    exit;      // Exit if accessed directly

class Cep_Post_Card_Pro_Elementor_Widget extends Widget_Base {

    //Function for get the slug of the element name.
    public function get_name() {
        return 'post-card-elementor-widget';
    }

    //Function for get the name of the element.
    public function get_title() {
        return esc_html__('Post Card', CEPE_DOMAIN);
    }

    //Function for get the icon of the element.
    public function get_icon() {
        return 'eicon-gallery-grid';
    }

    //Function for include element into the category.
    public function get_categories() {
        return ['card-elements'];
    }

    /*
     * Adding the controls fields for the Card Elements
     */

    protected function _register_controls() {

        /*
         * Start post card controls fields
         */
        $this->start_controls_section(
                'section_layout', array(
            'label' => esc_html__('Post Layout', CEPE_DOMAIN),
                )
        );

        $this->add_control(
                'post_card_style', [
            'label' => esc_html__('Post Card Style', CEPE_DOMAIN),
            'type' => Controls_Manager::SELECT,
            'options' => [
                'post-card-style-1' => esc_html__('Card Style 1', CEPE_DOMAIN),
                'post-card-style-2' => esc_html__('Card Style 2', CEPE_DOMAIN),
                'post-card-style-3' => esc_html__('Card Style 3', CEPE_DOMAIN),
                'post-card-style-4' => esc_html__('Card Style 4', CEPE_DOMAIN),
                'post-card-style-5' => esc_html__('Card Style 5', CEPE_DOMAIN),
                'post-card-style-6' => esc_html__('Card Style 6', CEPE_DOMAIN),
            ],
            'default' => 'post-card-style-1',
                ]
        );

        $this->add_responsive_control(
                'post_card_columns', [
            'label' => esc_html__('Columns', CEPE_DOMAIN),
            'type' => Controls_Manager::SELECT,
            'default' => '3',
            'tablet_default' => '2',
            'mobile_default' => '1',
            'options' => [
                '1' => esc_html__('1', CEPE_DOMAIN),
                '2' => esc_html__('2', CEPE_DOMAIN),
                '3' => esc_html__('3', CEPE_DOMAIN),
                '4' => esc_html__('4', CEPE_DOMAIN),
                '5' => esc_html__('5', CEPE_DOMAIN),
                '6' => esc_html__('6', CEPE_DOMAIN),
            ],
            'prefix_class' => 'elementor-grid%s-',
            'frontend_available' => true,
            'selectors' => [
                '.elementor-msie {{WRAPPER}} .elementor-post-item' => 'width: calc( 100% / {{SIZE}} )',
            ],
                ]
        );

        $this->add_control(
                'number_of_posts', [
            'label' => esc_html__('Display No. of Posts', CEPE_DOMAIN),
            'type' => Controls_Manager::NUMBER,
            'default' => 6,
                ]
        );

        $this->add_group_control(
                Group_Control_Image_Size::get_type(), [
            'name' => 'post_image_size',
            'exclude' => ['custom'],
            'default' => 'medium_large',
                ]
        );

        $this->add_control(
                'show_title', [
            'label' => esc_html__('Show Title', CEPE_DOMAIN),
            'type' => Controls_Manager::SWITCHER,
            'default' => 'yes',
            'label_off' => __('Off', CEPE_DOMAIN),
            'label_on' => __('On', CEPE_DOMAIN),
            'separator' => 'before',
                ]
        );

        $this->add_control(
                'title_tag', [
            'label' => esc_html__('Title HTML Tag', CEPE_DOMAIN),
            'type' => Controls_Manager::SELECT,
            'options' => [
                'h1' => esc_html__('H1', CEPE_DOMAIN),
                'h2' => esc_html__('H2', CEPE_DOMAIN),
                'h3' => esc_html__('H3', CEPE_DOMAIN),
                'h4' => esc_html__('H4', CEPE_DOMAIN),
                'h5' => esc_html__('H5', CEPE_DOMAIN),
                'h6' => esc_html__('H6', CEPE_DOMAIN),
                'div' => esc_html__('div', CEPE_DOMAIN),
                'span' => esc_html__('span', CEPE_DOMAIN),
                'p' => esc_html__('p', CEPE_DOMAIN),
            ],
            'default' => 'h2',
            'condition' => [
                'show_title' => 'yes',
            ],
                ]
        );

        $this->add_control(
                'show_excerpt', [
            'label' => esc_html__('Excerpt', CEPE_DOMAIN),
            'type' => Controls_Manager::SWITCHER,
            'label_on' => esc_html__('Show', CEPE_DOMAIN),
            'label_off' => esc_html__('Hide', CEPE_DOMAIN),
            'default' => 'yes',
                ]
        );

        $this->add_control(
                'excerpt_length', [
            'label' => esc_html__('Excerpt Length', CEPE_DOMAIN),
            'type' => Controls_Manager::NUMBER,
            'default' => apply_filters('excerpt_length', 25),
            'condition' => ['show_excerpt' => 'yes'],
                ]
        );
        $this->add_control(
                'excerpt_from', [
            'label' => esc_html__('Excerpt From', CEPE_DOMAIN),
            'type' => Controls_Manager::SELECT,
            'options' => [
                'content' => esc_html__('Content', CEPE_DOMAIN),
                'excerpt' => esc_html__('Excerpt', CEPE_DOMAIN),
            ],
            'default' => 'content',
            'condition' => [
                'show_excerpt' => 'yes',
            ],
                ]
        );

        $this->add_control(
                'show_read_more', [
            'label' => esc_html__('Read More', CEPE_DOMAIN),
            'type' => Controls_Manager::SWITCHER,
            'label_on' => esc_html__('Show', CEPE_DOMAIN),
            'label_off' => esc_html__('Hide', CEPE_DOMAIN),
            'default' => 'yes',
            'separator' => 'before',
                ]
        );

        $this->add_control(
                'read_more_text', [
            'label' => esc_html__('Read More Text', CEPE_DOMAIN),
            'type' => Controls_Manager::TEXT,
            'default' => esc_html__('Read More »', CEPE_DOMAIN),
            'condition' => ['show_read_more' => 'yes'],
                ]
        );

        $this->add_control(
                'show_meta_data', [
            'label' => esc_html__('Show Meta Data', CEPE_DOMAIN),
            'type' => Controls_Manager::SWITCHER,
            'label_on' => esc_html__('Show', CEPE_DOMAIN),
            'label_off' => esc_html__('Hide', CEPE_DOMAIN),
            'default' => 'yes',
            'separator' => 'before',
                ]
        );

        $this->add_control(
                'meta_data', [
            'label' => esc_html__('Meta Data', CEPE_DOMAIN),
            'label_block' => true,
            'type' => Controls_Manager::SELECT2,
            'default' => ['author', 'date', 'comments', 'tags'],
            'multiple' => true,
            'options' => [
                'author' => esc_html__('Author', CEPE_DOMAIN),
                'date' => esc_html__('Date', CEPE_DOMAIN),
                'comments' => esc_html__('Comments', CEPE_DOMAIN),
                'tags' => esc_html__('Tags', CEPE_DOMAIN),
            ],
            'condition' => ['show_meta_data' => 'yes'],
            'separator' => 'before',
                ]
        );

        $this->end_controls_section();


        $this->start_controls_section(
                'section_post_query', array(
            'label' => esc_html__('Query', CEPE_DOMAIN),
                )
        );

        $this->add_control(
                'blog_categories', [
            'label' => esc_html__('Categories', CEPE_DOMAIN),
            'type' => Controls_Manager::SELECT2,
            'label_block' => true,
            'multiple' => true,
            'description' => esc_html__('Select the categories you want to show', CEPE_DOMAIN),
            'options' => cep_post_categories(),
                ]
        );

        $this->add_control(
                'exclude_blog_categories', [
            'label' => esc_html__('Exclude Above Categories', CEPE_DOMAIN),
            'type' => Controls_Manager::SWITCHER,
            'label_on' => esc_html__('Yes', CEPE_DOMAIN),
            'label_off' => esc_html__('NO', CEPE_DOMAIN),
            'default' => 'no',
                ]
        );

        $this->add_control(
                'blog_tags', [
            'label' => esc_html__('Tags', CEPE_DOMAIN),
            'type' => Controls_Manager::SELECT2,
            'label_block' => true,
            'multiple' => true,
            'description' => esc_html__('Select the tags you want to show', CEPE_DOMAIN),
            'options' => cep_post_tags(),
            'separator' => 'before',
                ]
        );

        $this->add_control(
                'exclude_blog_tags', [
            'label' => esc_html__('Exclude Above Tags', CEPE_DOMAIN),
            'type' => Controls_Manager::SWITCHER,
            'label_on' => esc_html__('Yes', CEPE_DOMAIN),
            'label_off' => esc_html__('NO', CEPE_DOMAIN),
            'default' => 'no',
                ]
        );

        $this->add_control(
                'blog_author', [
            'label' => esc_html__('Author', CEPE_DOMAIN),
            'type' => Controls_Manager::SELECT2,
            'label_block' => true,
            'multiple' => true,
            'description' => esc_html__('Select the author you want to show', CEPE_DOMAIN),
            'options' => cep_post_author(),
            'separator' => 'before',
                ]
        );

        $this->add_control(
                'exclude_blog_authors', [
            'label' => esc_html__('Exclude Above Authors', CEPE_DOMAIN),
            'type' => Controls_Manager::SWITCHER,
            'label_on' => esc_html__('Yes', CEPE_DOMAIN),
            'label_off' => esc_html__('NO', CEPE_DOMAIN),
            'default' => 'no',
                ]
        );

        $this->add_control(
                'post_offset', [
            'label' => esc_html__('Offset', CEPE_DOMAIN),
            'type' => Controls_Manager::NUMBER,
            'default' => 0,
            'description' => esc_html__('Use this setting to skip over posts (e.g. \'2\' to skip over 2 posts).', CEPE_DOMAIN),
            'separator' => 'before',
                ]
        );

        $this->add_control(
                'advanced', [
            'label' => esc_html__('Advanced', CEPE_DOMAIN),
            'type' => Controls_Manager::HEADING,
            'separator' => 'before',
                ]
        );

        $this->add_control(
                'post_card_orderby', [
            'label' => esc_html__('Order By', CEPE_DOMAIN),
            'type' => Controls_Manager::SELECT,
            'default' => 'post_date',
            'options' => [
                'post_date' => esc_html__('Date', CEPE_DOMAIN),
                'post_title' => esc_html__('Title', CEPE_DOMAIN),
                'menu_order' => esc_html__('Menu Order', CEPE_DOMAIN),
                'rand' => esc_html__('Random', CEPE_DOMAIN),
            ],
                ]
        );

        $this->add_control(
                'post_sort_order', [
            'label' => esc_html__('Sort By', CEPE_DOMAIN),
            'type' => Controls_Manager::SELECT,
            'default' => 'desc',
            'options' => [
                'asc' => esc_html__('ASC', CEPE_DOMAIN),
                'desc' => esc_html__('DESC', CEPE_DOMAIN),
            ],
                ]
        );

        $this->end_controls_section();
        /*
         * End post card control
         */


        /*
         * Start control style tab for post card
         * Start name control style
         */
        $this->start_controls_section(
                'section_design_layout', [
            'label' => esc_html__('Layout', CEPE_DOMAIN),
            'tab' => Controls_Manager::TAB_STYLE,
                ]
        );
        $this->add_control(
                'post_card_grid_gap', [
            'label' => esc_html__('Grid Gap', CEPE_DOMAIN),
            'type' => Controls_Manager::SLIDER,
            'default' => [
                'size' => 30,
            ],
            'range' => [
                'px' => [
                    'min' => 0,
                    'max' => 100,
                ],
            ],
            'frontend_available' => true,
            'selectors' => [
                '{{WRAPPER}} .post-card-grid-gap' => 'grid-column-gap: {{SIZE}}{{UNIT}};',
            ],
                ]
        );

        $this->add_control(
                'post_card_row_gap', [
            'label' => esc_html__('Rows Gap', CEPE_DOMAIN),
            'type' => Controls_Manager::SLIDER,
            'default' => [
                'size' => 35,
            ],
            'range' => [
                'px' => [
                    'min' => 0,
                    'max' => 100,
                ],
            ],
            'frontend_available' => true,
            'selectors' => [
                '{{WRAPPER}} .post-card-container,
				 {{WRAPPER}} .card-style-6' => 'margin-bottom: {{SIZE}}{{UNIT}};',
            ],
                ]
        );

        $this->add_control(
                'post_card_border_radius', [
            'label' => esc_html__('Border Radius', CEPE_DOMAIN),
            'type' => Controls_Manager::DIMENSIONS,
            'size_units' => ['px', '%'],
            'selectors' => [
                '{{WRAPPER}} .post-card-box-radius' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
            ],
            'condition' => [
                'post_card_style' => ['post-card-style-2', 'post-card-style-6']
            ],
                ]
        );

        $this->add_control(
                'alignment', [
            'label' => esc_html__('Alignment', CEPE_DOMAIN),
            'type' => Controls_Manager::CHOOSE,
            'label_block' => false,
            'options' => [
                'left' => [
                    'title' => esc_html__('Left', CEPE_DOMAIN),
                    'icon' => 'eicon-text-align-left',
                ],
                'center' => [
                    'title' => esc_html__('Center', CEPE_DOMAIN),
                    'icon' => 'eicon-text-align-center',
                ],
                'right' => [
                    'title' => esc_html__('Right', CEPE_DOMAIN),
                    'icon' => 'eicon-text-align-right',
                ],
                'justify' => [
                    'title' => esc_html__('Justify', CEPE_DOMAIN),
                    'icon' => 'eicon-text-align-justify',
                ],
            ],
            'default' => 'left',
            'prefix_class' => 'elementor-posts--align-',
            'selectors' => [
                '{{WRAPPER}} .post-card-alignment,
		 {{WRAPPER}} .card_aling,
		 {{WRAPPER}} .card-category,
                 {{WRAPPER}} .card_title' => 'text-align: {{VALUE}};',
            ],
                ]
        );

        $this->end_controls_section();


        $this->start_controls_section(
                'section_design_image_layout', [
            'label' => esc_html__('Image', CEPE_DOMAIN),
            'tab' => Controls_Manager::TAB_STYLE,
                ]
        );

        $this->add_control(
                'img_border_radius', [
            'label' => esc_html__('Border Radius', CEPE_DOMAIN),
            'type' => Controls_Manager::DIMENSIONS,
            'size_units' => ['px', '%'],
            'selectors' => [
                '{{WRAPPER}} .post-card-item_img, {{WRAPPER}} .post-card-item_img a img, {{WRAPPER}} .elementor-post-item__overlay, {{WRAPPER}} .post-card-style-6 .card' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
            ],
                ]
        );

        $this->start_controls_tabs('thumbnail_effects_tabs');

        $this->start_controls_tab('normal', [
            'label' => esc_html__('Normal', CEPE_DOMAIN),
                ]
        );

        $this->add_group_control(
                Group_Control_Css_Filter::get_type(), [
            'name' => 'thumbnail_filters',
            'selector' => '{{WRAPPER}} .post-card_thumbnail img',
                ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab('hover', [
            'label' => esc_html__('Hover', CEPE_DOMAIN),
                ]
        );

        $this->add_group_control(
                Group_Control_Css_Filter::get_type(), [
            'name' => 'thumbnail_hover_filters',
            'selector' => '{{WRAPPER}} .elementor-post:hover .post-card_thumbnail:hover img, {{WRAPPER}} .elementor-post-item__overlay a img:hover',
                ]
        );

        $this->end_controls_tab();

        $this->end_controls_tabs();

        $this->end_controls_section();


        $this->start_controls_section(
                'section_design_content_bg', [
            'label' => esc_html__('Background Color', CEPE_DOMAIN),
            'tab' => Controls_Manager::TAB_STYLE,
                ]
        );

        $this->add_control(
                'section_design_bg_color', [
            'label' => esc_html__('Background Color', CEPE_DOMAIN),
            'type' => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .post-card-container .entry-content' => 'background-color: {{VALUE}};',
            ],
                ]
        );

        $this->add_control(
                'category_bg_color', [
            'label' => esc_html__('Category Color', CEPE_DOMAIN),
            'type' => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .post-card_category_background' => 'background-color: {{VALUE}};',
            ],
            'condition' => ['post_card_style' => 'post-card-style-1'],
                ]
        );

        $this->add_control(
                'date_bg_color', [
            'label' => esc_html__('Date Color', CEPE_DOMAIN),
            'type' => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .post-card_date' => 'background-color: {{VALUE}};',
            ],
            'condition' => ['post_card_style' => 'post-card-style-1'],
                ]
        );

        $this->add_control(
                'content_box_bg_color', [
            'label' => esc_html__('Content Box Color', CEPE_DOMAIN),
            'type' => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .post-card-content-box, {{WRAPPER}} .post-card-content-bg-box' => 'background-color: {{VALUE}};',
            ],
            'condition' => ['post_card_style' => 'post-card-style-1', 'post_card_style' => 'post-card-style-2', 'post_card_style' => 'post-card-style-3', 'post_card_style' => 'post-card-style-4'],
                ]
        );

        $this->end_controls_section();


        $this->start_controls_section(
                'section_design_content', [
            'label' => esc_html__('Content', CEPE_DOMAIN),
            'tab' => Controls_Manager::TAB_STYLE,
                ]
        );

        $this->add_control(
                'date_style', [
            'label' => esc_html__('Date', CEPE_DOMAIN),
            'type' => Controls_Manager::HEADING,
                ]
        );

        $this->add_control(
                'date_color', [
            'label' => esc_html__('Color', CEPE_DOMAIN),
            'type' => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .post-card_date_color,
				 {{WRAPPER}} .card-style-6 .card-time' => 'color: {{VALUE}};',
            ],
                ]
        );

        $this->add_control(
                'date_hover_color', [
            'label' => esc_html__('Hover Color', CEPE_DOMAIN),
            'type' => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .post-card_date_color:hover' => 'color: {{VALUE}};',
            ],
            'condition' => [
                'post_card_style' => 'post-card-style-5'
            ],
                ]
        );

        $this->add_control(
                'date_background_color', [
            'label' => esc_html__('Background Color', CEPE_DOMAIN),
            'type' => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .post-card_date_color' => 'background-color: {{VALUE}};',
            ],
            'condition' => [
                'post_card_style' => 'post-card-style-3'
            ],
                ]
        );

        $this->add_control(
                'category_style', [
            'label' => esc_html__('Category', CEPE_DOMAIN),
            'type' => Controls_Manager::HEADING,
                ]
        );

        $this->add_control(
                'category_color', [
            'label' => esc_html__('Color', CEPE_DOMAIN),
            'type' => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .post-card_category,
		{{WRAPPER}} .cat-links a,
		{{WRAPPER}} .post-content .post-card_category,
		{{WRAPPER}} .post-card_category a,
		{{WRAPPER}} .card-style-6 .card-category' => 'color: {{VALUE}};',
            ],
                ]
        );

        $this->add_control(
                'category_hover_color', [
            'label' => esc_html__('Hover Color', CEPE_DOMAIN),
            'type' => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .post-card_category,
		{{WRAPPER}} .cat-links a:hover,
		{{WRAPPER}} .post-card_category:hover span.cat-links a,
		{{WRAPPER}} .post-content .post-card_category a:hover,
		{{WRAPPER}} .card-style-6 .card-category' => 'color: {{VALUE}};',
            ],
                ]
        );

        $this->add_group_control(
                Group_Control_Typography::get_type(), [
            'name' => 'cateogry_typography',
            'selector' => '{{WRAPPER}} .post-card_category, {{WRAPPER}} .post-card_category a',
                ]
        );

        $this->add_control(
                'category_spacing', [
            'label' => esc_html__('Spacing', CEPE_DOMAIN),
            'type' => Controls_Manager::SLIDER,
            'range' => [
                'px' => [
                    'max' => 100,
                ],
            ],
            'selectors' => [
                '{{WRAPPER}} .post-card_category' => 'margin-bottom: {{SIZE}}{{UNIT}};',
            ],
                ]
        );

        $this->add_control(
                'heading_title_style', [
            'label' => esc_html__('Title', CEPE_DOMAIN),
            'type' => Controls_Manager::HEADING,
            'condition' => ['show_title' => 'yes'],
                ]
        );

        $this->add_control(
                'title_color', [
            'label' => esc_html__('Color', CEPE_DOMAIN),
            'type' => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .post-card_title,
		{{WRAPPER}} .post-card_title a,
		{{WRAPPER}} .card-style-6 .card-title a' => 'color: {{VALUE}};',
            ],
            'condition' => [
                'show_title' => 'yes'
            ],
                ]
        );
        $this->add_control(
                'title_hover_color', [
            'label' => esc_html__('Hover Color', CEPE_DOMAIN),
            'type' => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .post-card_title:hover,
		{{WRAPPER}} .post-card_title:hover a,
		{{WRAPPER}} .title a.post-card_title:hover' => 'color: {{VALUE}};',
            ],
            'condition' => [
                'show_title' => 'yes',
                'condition' => ['post_card_style' => 'post-card-style-1', 'post_card_style' => 'post-card-style-2', 'post_card_style' => 'post-card-style-3', 'post_card_style' => 'post-card-style-4', 'post_card_style' => 'post-card-style-5'],
            ],
                ]
        );

        $this->add_group_control(
                Group_Control_Typography::get_type(), [
            'name' => 'title_typography',
            'selector' => '{{WRAPPER}} .post-card_title, {{WRAPPER}} .post-card_title a, {{WRAPPER}} .card-style-6 .card-title a',
            'condition' => [
                'show_title' => 'yes'
            ],
                ]
        );

        $this->add_control(
                'title_spacing', [
            'label' => esc_html__('Spacing', CEPE_DOMAIN),
            'type' => Controls_Manager::SLIDER,
            'range' => [
                'px' => [
                    'max' => 100,
                ],
            ],
            'selectors' => [
                '{{WRAPPER}} .post-card_title,
                {{WRAPPER}} .card-style-6 .card-title' => 'margin-bottom: {{SIZE}}{{UNIT}};',
            ],
            'condition' => [
                'show_title' => 'yes'
            ],
                ]
        );

        $this->add_control(
                'heading_excerpt_style', [
            'label' => esc_html__('Excerpt', CEPE_DOMAIN),
            'type' => Controls_Manager::HEADING,
            'separator' => 'before',
            'condition' => [
                'show_excerpt' => 'yes'
            ],
                ]
        );

        $this->add_control(
                'excerpt_color', [
            'label' => esc_html__('Color', CEPE_DOMAIN),
            'type' => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .post-card_excerpt' => 'color: {{VALUE}};',
            ],
            'condition' => [
                'show_excerpt' => 'yes'
            ],
                ]
        );

        $this->add_group_control(
                Group_Control_Typography::get_type(), [
            'name' => 'excerpt_typography',
            'selector' => '{{WRAPPER}} .post-card_excerpt',
            'condition' => [
                'show_excerpt' => 'yes'
            ],
                ]
        );

        $this->add_control(
                'excerpt_spacing', [
            'label' => esc_html__('Spacing', CEPE_DOMAIN),
            'type' => Controls_Manager::SLIDER,
            'range' => [
                'px' => [
                    'max' => 100,
                ],
            ],
            'selectors' => [
                '{{WRAPPER}} .post-card_excerpt' => 'margin-bottom: {{SIZE}}{{UNIT}};',
            ],
            'condition' => [
                'show_excerpt' => 'yes'
            ],
                ]
        );

        $this->add_control(
                'heading_readmore_style', [
            'label' => esc_html__('Read More', CEPE_DOMAIN),
            'type' => Controls_Manager::HEADING,
            'separator' => 'before',
            'condition' => [
                'show_read_more' => 'yes'
            ],
                ]
        );

        $this->add_control(
                'read_more_color', [
            'label' => esc_html__('Color', CEPE_DOMAIN),
            'type' => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .post-card_read-more' => 'color: {{VALUE}};',
            ],
            'condition' => [
                'show_read_more' => 'yes'
            ],
                ]
        );

        $this->add_control(
                'read_more_hover_color', [
            'label' => esc_html__('Hover Color', CEPE_DOMAIN),
            'type' => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .post-card_read-more:hover' => 'color: {{VALUE}};',
            ],
            'condition' => [
                'show_read_more' => 'yes'
            ],
                ]
        );

        $this->add_control(
                'read_more_background_color', [
            'label' => esc_html__('Background Color', CEPE_DOMAIN),
            'type' => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .post-card_read-more' => 'background-color: {{VALUE}};',
            ],
            'condition' => [
                'show_read_more' => 'yes', 'post_card_style' => 'post-card-style-3'
            ],
                ]
        );

        $this->add_group_control(
                Group_Control_Typography::get_type(), [
            'name' => 'read_more_typography',
            'selector' => '{{WRAPPER}} .post-card_read-more',
            'condition' => [
                'show_read_more' => 'yes'
            ],
                ]
        );

        $this->add_control(
                'heading_meta_style', [
            'label' => esc_html__('Meta', CEPE_DOMAIN),
            'description' => esc_html__('Show meta data', CEPE_DOMAIN),
            'type' => Controls_Manager::HEADING,
            'separator' => 'before',
            'condition' => ['show_meta_data' => 'yes'],
                ]
        );

        $this->add_control(
                'meta_color', [
            'label' => esc_html__('Icon Color', CEPE_DOMAIN),
            'type' => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .post_card_meta span .fa,
		{{WRAPPER}} .post-card_meta-data span .fa,
		{{WRAPPER}} .card-style-6 .card-by span .fa' => 'color: {{VALUE}};',
            ],
            'condition' => ['show_meta_data' => 'yes'],
                ]
        );

        $this->add_control(
                'meta_separator_color', [
            'label' => esc_html__('Text Color', CEPE_DOMAIN),
            'type' => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .post-card_meta-data span,
		{{WRAPPER}} .post-card_meta-data a,
		{{WRAPPER}} .post-card-style-5 .post-meta .post-card-tags .tags-links a,
		{{WRAPPER}} .post-card-style-5 .post-meta .post-card-tags .tags-links,
		{{WRAPPER}} .post-card-style-5 .post-bottom span a,
		{{WRAPPER}} .card-style-6 .card-by a' => 'color: {{VALUE}};',
            ],
            'condition' => ['show_meta_data' => 'yes'],
                ]
        );

        $this->add_control(
                'meta_separator_hover_color', [
            'label' => esc_html__('Text Hover Color', CEPE_DOMAIN),
            'type' => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .post-card_meta-data span, {{WRAPPER}} .post-card_meta-data a, {{WRAPPER}} .post-card-style-5 .post-bottom span a:hover, {{WRAPPER}} .post-card-style-5 .post-meta .tags-links:hover, {{WRAPPER}} .post-card-style-5 .post-meta .tags-links:hover a' => 'color: {{VALUE}};',
            ],
            'condition' => ['show_meta_data' => 'yes'],
                ]
        );

        $this->add_group_control(
                Group_Control_Typography::get_type(), [
            'name' => 'meta_typography',
            'selector' =>
                '{{WRAPPER}} .post-card_meta-data,
		{{WRAPPER}} .post-card_meta-data i .fa,
		{{WRAPPER}} .post-card_meta-data span a,
		{{WRAPPER}} .card-style-6 .card-by a',
            'condition' => ['show_meta_data' => 'yes'],
                ]
        );

        $this->add_control(
                'meta_spacing', [
            'label' => esc_html__('Spacing', CEPE_DOMAIN),
            'type' => Controls_Manager::SLIDER,
            'range' => [
                'px' => [
                    'max' => 100,
                ],
            ],
            'selectors' => [
                '{{WRAPPER}} .post-card_meta-data,
		{{WRAPPER}} .card-style-6 .card-by' => 'margin-bottom: {{SIZE}}{{UNIT}};',
            ],
            'condition' => ['show_meta_data' => 'yes'],
                ]
        );

        $this->end_controls_section();
        /*
         * End control style tab for post card
         */
    }

    /**
     * Render Card Elements widget output on the front-end.
     *
     * Written in PHP and used to generate the final HTML.
     *
     * @access protected
     */
    protected function render() {

        $settings = $this->get_settings_for_display();

        $card_style = $settings['post_card_style'];

        if ($settings['post_card_columns'] == "1") {
            $column = "elementor-grid-1";
        } elseif ($settings['post_card_columns'] == "2") {
            $column = "elementor-grid-2";
        } elseif ($settings['post_card_columns'] == "3") {
            $column = "elementor-grid-3";
        } elseif ($settings['post_card_columns'] == "4") {
            $column = "elementor-grid-4";
        } elseif ($settings['post_card_columns'] == "5") {
            $column = "elementor-grid-5";
        } elseif ($settings['post_card_columns'] == "6") {
            $column = "elementor-grid-6";
        }

        $args = array(
            'post_type' => 'post',
            'posts_per_page' => $settings['number_of_posts'],
            'post_status' => 'publish',
            'orderby' => $settings['post_card_orderby'],
            'order' => $settings['post_sort_order'],
            'offset' => $settings['post_offset'], // post_offset
        );

        // Exclude IN or NOT IN.
        if (isset($settings['exclude_blog_categories']) && !empty($settings['exclude_blog_categories'])) {
            $post_cats = 'NOT IN';
        } else {
            $post_cats = 'IN';
        }
        if (isset($settings['exclude_blog_tags']) && !empty($settings['exclude_blog_tags'])) {
            $post_tags = 'NOT IN';
        } else {
            $post_tags = 'IN';
        }
        if (isset($settings['exclude_blog_authors']) && !empty($settings['exclude_blog_authors'])) {
            $post_authors = 'author__not_in';
        } else {
            $post_authors = 'author__in';
        }

        // Query Check all Display Category, tags and Author 
        if (( isset($settings['blog_categories']) && !empty($settings['blog_categories']) ) && ( isset($settings['blog_tags']) && !empty($settings['blog_tags']) ) && ( isset($settings['blog_author']) && !empty($settings['blog_author']) )) {
            // Display All Post with Category, tags and Author // Condition AND
            $args['tax_query'][] = array(
                'relation' => 'AND',
                array(
                    'taxonomy' => 'category',
                    'field' => 'ID',
                    'terms' => $settings['blog_categories'],
                    'operator' => $post_cats,
                ),
                array(
                    'taxonomy' => 'post_tag',
                    'field' => 'ID',
                    'terms' => $settings['blog_tags'],
                    'operator' => $post_tags,
                ),
            );
            $args[$post_authors] = $settings['blog_author'];
        } elseif ((isset($settings['blog_categories']) && !empty($settings['blog_categories'])) && (isset($settings['blog_tags']) && !empty($settings['blog_tags']))) {
            // Display All Post with Category and Tags // Condition AND
            $args['tax_query'][] = array(
                'relation' => 'AND',
                array(
                    'taxonomy' => 'category',
                    'field' => 'ID',
                    'terms' => $settings['blog_categories'],
                    'operator' => $post_cats,
                ),
                array(
                    'taxonomy' => 'post_tag',
                    'field' => 'ID',
                    'terms' => $settings['blog_tags'],
                    'operator' => $post_tags,
                ),
            );
        } elseif ((isset($settings['blog_categories']) && !empty($settings['blog_categories'])) && (isset($settings['blog_author']) && !empty($settings['blog_author']))) {
            // Display All Post with Category and Author // Condition AND            
            $args['tax_query'][] = array(
                'relation' => 'AND',
                array(
                    'taxonomy' => 'category',
                    'field' => 'ID',
                    'terms' => $settings['blog_categories'],
                    'operator' => $post_cats,
                ),
            );
            $args[$post_authors] = $settings['blog_author'];
        } elseif ((isset($settings['blog_tags']) && !empty($settings['blog_tags'])) && (isset($settings['blog_author']) && !empty($settings['blog_author']))) {
            // Display All Post with Tags and Author // Condition AND
            $args['tax_query'][] = array(
                'relation' => 'AND',
                array(
                    'taxonomy' => 'post_tag',
                    'field' => 'ID',
                    'terms' => $settings['blog_tags'],
                    'operator' => $post_tags,
                ),
            );
            $args[$post_authors] = $settings['blog_author'];
        } elseif (isset($settings['blog_categories']) && !empty($settings['blog_categories'])) {
            // Display All Post with Category 
            $args['tax_query'][] = array(
                array(
                    'taxonomy' => 'category',
                    'field' => 'ID',
                    'terms' => $settings['blog_categories'],
                    'operator' => $post_cats,
                ),
            );
        } elseif (isset($settings['blog_tags']) && !empty($settings['blog_tags'])) {
            // Display All Post with Tags 
            $args['tax_query'][] = array(
                array(
                    'taxonomy' => 'post_tag',
                    'field' => 'ID',
                    'terms' => $settings['blog_tags'],
                    'operator' => $post_tags,
                ),
            );
        } elseif (isset($settings['blog_author']) && !empty($settings['blog_author'])) {
            // Display All Post with Authors
            $args[$post_authors] = $settings['blog_author'];
        }

        $blog_posts = new \WP_Query($args);

        if ($blog_posts->have_posts()) :
            ?> 
            <div class="post_card grid-container post-card-grid-gap elementor-grid <?php echo $card_style . ' ' . $column; ?>" > 
                <?php
                while ($blog_posts->have_posts()) : $blog_posts->the_post();

                    switch ($settings['post_card_style']) {
                        case 'post-card-style-1':
                            include CEPE_PATH . 'include/post-card/elementor-post-card-1.php';  // Card Style 1 
                            break;
                        case 'post-card-style-2':
                            include CEPE_PATH . 'include/post-card/elementor-post-card-2.php';  // Card Style 2
                            break;
                        case 'post-card-style-3':
                            include CEPE_PATH . 'include/post-card/elementor-post-card-3.php';  // Card Style 3
                            break;
                        case 'post-card-style-4':
                            include CEPE_PATH . 'include/post-card/elementor-post-card-4.php';  // Card Style 4
                            break;
                        case 'post-card-style-5':
                            include CEPE_PATH . 'include/post-card/elementor-post-card-5.php';  // Card Style 5
                            break;
                        case 'post-card-style-6':
                            include CEPE_PATH . 'include/post-card/elementor-post-card-6.php';  // Card Style 6
                            break;
                        default:
                            include CEPE_PATH . 'include/post-card/elementor-post-card-1.php';  // Default Card Style 1
                            break;
                    }

                endwhile;
                wp_reset_postdata();
                ?>
            </div> 
            <?php
        endif;
    }

}

Plugin::instance()->widgets_manager->register_widget_type(new Cep_Post_Card_Pro_Elementor_Widget());
