<?php

namespace Elementor;

if (!defined('ABSPATH'))
    exit;      // Exit if accessed directly

class Cep_Profile_Card_Pro_Elementor_Widget extends Widget_Base {

    //Function for get the slug of the element name.
    public function get_name() {
        return 'profile-card-elementor-widget';
    }

    //Function for get the name of the element.
    public function get_title() {
        return esc_html__('Profile Card', CEPE_DOMAIN);
    }

    //Function for get the icon of the element.
    public function get_icon() {
        return 'eicon-icon-box';
    }

    //Function for include element into the category.
    public function get_categories() {
        return ['card-elements'];
    }

    /*
     * Adding the controls fields for the Card Elements
     */
    protected function _register_controls() {

        /*
         * Start profile card controls fields
         */
        $this->start_controls_section(
                'section_items_data', array(
            'label' => esc_html__('Profile Card Items', CEPE_DOMAIN),
                )
        );

        $this->add_control(
                'profile_card_style', [
            'label' => esc_html__('Profile Card Style', CEPE_DOMAIN),
            'type' => Controls_Manager::SELECT,
            'options' => [
                'profile-card-style-1'  => esc_html__('Card Style 1', CEPE_DOMAIN),
                'profile-card-style-2'  => esc_html__('Card Style 2', CEPE_DOMAIN),
                'profile-card-style-3'  => esc_html__('Card Style 3', CEPE_DOMAIN),
                'profile-card-style-4'  => esc_html__('Card Style 4', CEPE_DOMAIN),
                'profile-card-style-5'  => esc_html__('Card Style 5', CEPE_DOMAIN),
                'profile-card-style-6'  => esc_html__('Card Style 6', CEPE_DOMAIN),
                'profile-card-style-7'  => esc_html__('Card Style 7', CEPE_DOMAIN),
                'profile-card-style-8'  => esc_html__('Card Style 8', CEPE_DOMAIN),
                'profile-card-style-9'  => esc_html__('Card Style 9', CEPE_DOMAIN),
                'profile-card-style-10' => esc_html__('Card Style 10', CEPE_DOMAIN),
                'profile-card-style-11' => esc_html__('Card Style 11', CEPE_DOMAIN),
            ],
            'default' => 'profile-card-style-1',
                ]
        );

        $this->add_control(
                'name', [
            'label'         => esc_html__('Name', CEPE_DOMAIN),
            'type'          => Controls_Manager::TEXT,
            'default'       => esc_html__('John Doe', CEPE_DOMAIN),
            'placeholder'   => esc_html__('Enter your name', CEPE_DOMAIN),
                ]
        );

        $this->add_control(
                'position', [
            'label'         => esc_html__('Position', CEPE_DOMAIN),
            'type'          => Controls_Manager::TEXT,
            'default'       => esc_html__('Developer', CEPE_DOMAIN),
            'placeholder'   => esc_html__('Developer', CEPE_DOMAIN),
                ]
        );

        $this->add_control(
                'display_profile_description', [
            'label'         => esc_html__('Display Profile Description', CEPE_DOMAIN),
            'type'          => Controls_Manager::SWITCHER,
            'default'       => 'yes',
            'label_on'      => esc_html__('Show', CEPE_DOMAIN),
            'label_off'     => esc_html__('Hide', CEPE_DOMAIN),
            'condition'     => [
                'profile_card_style' => [
                    'profile-card-style-1',
                    'profile-card-style-2',
                    'profile-card-style-3',
                    'profile-card-style-4',
                    'profile-card-style-5',
                    'profile-card-style-6',
                    'profile-card-style-7',
                    'profile-card-style-8',
                    'profile-card-style-9',
                    'profile-card-style-10',
                    'profile-card-style-11'
                ],
            ],
                ]
        );

        $this->add_control(
                'profile_description', array(
            'label'         => esc_html__('Description', CEPE_DOMAIN),
            'type'          => Controls_Manager::TEXTAREA,
            'condition'     => [
                'display_profile_description' => 'yes',
                'profile_card_style' => [
                    'profile-card-style-1',
                    'profile-card-style-2',
                    'profile-card-style-3',
                    'profile-card-style-4',
                    'profile-card-style-5',
                    'profile-card-style-6',
                    'profile-card-style-7',
                    'profile-card-style-8',
                    'profile-card-style-9',
                    'profile-card-style-10',
                    'profile-card-style-11'
                ],
            ],
            'default'       => esc_html__('Lorem ipsum dolor sit amet, consectetur adipisci ng elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.', CEPE_DOMAIN),
                )
        );

        $this->add_control(
                'profile_image', [
            'label'         => esc_html__('Profile Image', CEPE_DOMAIN),
            'type'          => Controls_Manager::MEDIA,
            'dynamic'       => [
                'active' => true,
            ],
            'default'       => [
                'url'       => Utils::get_placeholder_image_src(),
            ],
                ]
        );

        $this->add_control(
                'profile_background_image', [
            'label'         => esc_html__('Profile Background Image', CEPE_DOMAIN),
            'type'          => Controls_Manager::MEDIA,
            'dynamic'       => [
                'active' => true,
            ],
            'condition'     => [
                'profile_card_style' => ['profile-card-style-6'],
            ],
            'default'       => [
                'url' => Utils::get_placeholder_image_src(),
            ],
                ]
        );

        $this->end_controls_section();
        /*
         * End profile card controls fields
         */

        /*
         * Start Social Media control for profile card
         */
        $this->start_controls_section(
                'section_social_media', array(
            'label'         => esc_html__('Social Media', CEPE_DOMAIN),
                )
        );

        $this->add_control(
                'display_social_icon', [
            'label'         => esc_html__('Display Social Icon', CEPE_DOMAIN),
            'type'          => Controls_Manager::SWITCHER,
            'default'       => 'yes',
            'label_on'      => esc_html__('Show', CEPE_DOMAIN),
            'label_off'     => esc_html__('Hide', CEPE_DOMAIN),
                ]
        );

        $repeater = new Repeater();

        $repeater->add_control(
                'social', [
            'label'         => esc_html__( 'Icon', CEPE_DOMAIN ),
            'type'          => Controls_Manager::ICONS,
            'default'       => [
                'value'     => 'fab fa-facebook',
                'library'   => 'fa-brands',
            ],
            'fa4compatibility' => 'icon',
                ]
        );

        $repeater->add_control(
                'link', [
            'label'         => esc_html__('Link', CEPE_DOMAIN),
            'type'          => Controls_Manager::URL,
            'label_block'   => true,
            'default'       => [
                'is_external' => 'true',
            ],
            'placeholder'   => esc_html__('https://your-link.com', CEPE_DOMAIN),
                ]
        );

        $this->add_control(
                'social_icon_list', [
            'label'         => esc_html__('Icons List', CEPE_DOMAIN),
            'type'          => Controls_Manager::REPEATER,
            'fields'        => $repeater->get_controls(),
            'condition'     => [
                'display_social_icon' => 'yes',
            ],
            'title_field'   => '{{{ elementor.helpers.renderIcon( this, social, {}, "i", "panel" ) || \'<i class="{{ icon }}" aria-hidden="true"></i>\' }}}',
                ]
        );

        $this->add_control(
                'shape', [
            'label'         => esc_html__('Shape', CEPE_DOMAIN),
            'type'          => Controls_Manager::SELECT,
            'default'       => 'rounded',
            'options'       => [
                'rounded'   => esc_html__('Rounded', CEPE_DOMAIN),
                'square'    => esc_html__('Square', CEPE_DOMAIN),
                'circle'    => esc_html__('Circle', CEPE_DOMAIN),
            ],
            'prefix_class'  => 'elementor-shape-',
            'condition'     => [
                'display_social_icon' => 'yes',
            ],
                ]
        );

        $this->add_responsive_control(
                'social_icon_align', [
            'label'         => esc_html__('Alignment', CEPE_DOMAIN),
            'type'          => Controls_Manager::CHOOSE,
            'options'       => [
                'left'      => [
                    'title' => esc_html__('Left', CEPE_DOMAIN),
                    'icon'  => 'eicon-text-align-left',
                ],
                'center'    => [
                    'title' => esc_html__('Center', CEPE_DOMAIN),
                    'icon'  => 'eicon-text-align-center',
                ],
                'right'     => [
                    'title' => esc_html__('Right', CEPE_DOMAIN),
                    'icon'  => 'eicon-text-align-right',
                ],
            ],
            'default'       => 'center',
            'selectors'     => [
                '{{WRAPPER}} .elementor-social-icons-wrapper' => 'text-align: {{VALUE}};',
            ],
            'condition'     => [
                'display_social_icon' => 'yes',
            ],
                ]
        );

        $this->end_controls_section();
        /*
         * End Social Media control for profile card
         */


        /*
         * Start control style tab for profile card
         * Start name control style
         */
        $this->start_controls_section(
                'section_profile_name', [
            'label'         => esc_html__('Name', CEPE_DOMAIN),
            'tab'           => Controls_Manager::TAB_STYLE,
                ]
        );

        $this->add_responsive_control(
                'name_text_align', [
            'label'         => esc_html__('Alignment', CEPE_DOMAIN),
            'type'          => Controls_Manager::CHOOSE,
            'options'       => [
                'left'      => [
                    'title' => esc_html__('Left', CEPE_DOMAIN),
                    'icon'  => 'eicon-text-align-left',
                ],
                'center'    => [
                    'title' => esc_html__('Center', CEPE_DOMAIN),
                    'icon'  => 'eicon-text-align-center',
                ],
                'right'     => [
                    'title' => esc_html__('Right', CEPE_DOMAIN),
                    'icon'  => 'eicon-text-align-right',
                ],
                'justify'   => [
                    'title' => esc_html__('Justified', CEPE_DOMAIN),
                    'icon'  => 'eicon-text-align-justify',
                ],
            ],
            'selectors'     => [
                '{{WRAPPER}} .elementor-profile-name-wrapper,
		{{WRAPPER}} .profile-card-style-11 .name' => 'text-align: {{VALUE}};',
            ],
                ]
        );

        $this->add_control(
                'name_color', [
            'label'         => esc_html__('Text Color', CEPE_DOMAIN),
            'type'          => Controls_Manager::COLOR,
            'selectors'     => [
                '{{WRAPPER}} .elementor-profile-name-wrapper,
		{{WRAPPER}} .profile-card-style-11 .name' => 'color: {{VALUE}};',
            ],
                ]
        );

        $this->add_group_control(
                Group_Control_Typography::get_type(), [
            'name'          => 'typography_name',
            'selector'      => '{{WRAPPER}} .elementor-profile-name-wrapper,
			    {{WRAPPER}} .profile-card-style-11 .name',
                ]
        );

        $this->end_controls_section();

        /*
         * Start position control style
         */
        $this->start_controls_section(
                'section_profile_position', [
            'label'         => esc_html__('Designation', CEPE_DOMAIN),
            'tab'           => Controls_Manager::TAB_STYLE,
                ]
        );

        $this->add_responsive_control(
                'position_text_align', [
            'label'         => esc_html__('Alignment', CEPE_DOMAIN),
            'type'          => Controls_Manager::CHOOSE,
            'options'       => [
                'left'      => [
                    'title' => esc_html__('Left', CEPE_DOMAIN),
                    'icon'  => 'eicon-text-align-left',
                ],
                'center'    => [
                    'title' => esc_html__('Center', CEPE_DOMAIN),
                    'icon'  => 'eicon-text-align-center',
                ],
                'right'     => [
                    'title' => esc_html__('Right', CEPE_DOMAIN),
                    'icon'  => 'eicon-text-align-right',
                ],
                'justify'   => [
                    'title' => esc_html__('Justified', CEPE_DOMAIN),
                    'icon'  => 'eicon-text-align-justify',
                ],
            ],
            'selectors'     => [
                '{{WRAPPER}} .elementor-profile-position-wrapper,
	            {{WRAPPER}} .profile-card-style-11 .position' => 'text-align: {{VALUE}};',
            ],
                ]
        );

        $this->add_control(
                'position_color', [
            'label'         => esc_html__('Text Color', CEPE_DOMAIN),
            'type'          => Controls_Manager::COLOR,
            'selectors'     => [
                '{{WRAPPER}} .elementor-profile-position-wrapper,
		        {{WRAPPER}} .profile-card-style-11 .position' => 'color: {{VALUE}};',
            ],
                ]
        );

        $this->add_group_control(
                Group_Control_Typography::get_type(), [
            'name'          => 'typography_position',
            'selector'      => '{{WRAPPER}} .elementor-profile-position-wrapper,
			    {{WRAPPER}} .profile-card-style-11 .position',
                ]
        );

        $this->end_controls_section();

        /*
         * Start description control style
         */
        $this->start_controls_section(
                'section_profile_description', [
            'label'         => esc_html__('Description', CEPE_DOMAIN),
            'tab'           => Controls_Manager::TAB_STYLE,
            'condition'     => [
                'profile_card_style' => [
                    'profile-card-style-1',
                    'profile-card-style-2',
                    'profile-card-style-3',
                    'profile-card-style-4',
                    'profile-card-style-5',
                    'profile-card-style-6',
                    'profile-card-style-7',
                    'profile-card-style-8',
                    'profile-card-style-9',
                    'profile-card-style-10',
                    'profile-card-style-11'
                ],
            ],
                ]
        );

        $this->add_responsive_control(
                'description_text_align', [
            'label'         => esc_html__('Alignment', CEPE_DOMAIN),
            'type'          => Controls_Manager::CHOOSE,
            'options'       => [
                'left'      => [
                    'title' => esc_html__('Left', CEPE_DOMAIN),
                    'icon'  => 'eicon-text-align-left',
                ],
                'center'    => [
                    'title' => esc_html__('Center', CEPE_DOMAIN),
                    'icon'  => 'eicon-text-align-center',
                ],
                'right'     => [
                    'title' => esc_html__('Right', CEPE_DOMAIN),
                    'icon'  => 'eicon-text-align-right',
                ],
                'justify'   => [
                    'title' => esc_html__('Justified', CEPE_DOMAIN),
                    'icon'  => 'eicon-text-align-justify',
                ],
            ],
            'selectors'     => [
                '{{WRAPPER}} .elementor-profile-description-wrapper' => 'text-align: {{VALUE}};',
            ],
                ]
        );

        $this->add_control(
                'description_color', [
            'label'         => esc_html__('Text Color', CEPE_DOMAIN),
            'type'          => Controls_Manager::COLOR,
            'selectors'     => [
                '{{WRAPPER}} .elementor-profile-description-wrapper,
                {{WRAPPER}} .profile-card-style-11 .description' => 'color: {{VALUE}};',
            ],
                ]
        );

        $this->add_group_control(
                Group_Control_Typography::get_type(), [
            'name'          => 'typography_description',
            'selector'      => '{{WRAPPER}} .elementor-profile-description-wrapper',
                ]
        );

        $this->end_controls_section();


        /*
         * Start content background control style
         */
        $this->start_controls_section(
                'section_content_background_style', [
            'label'         => esc_html__('Content Box Style', CEPE_DOMAIN),
            'tab'           => Controls_Manager::TAB_STYLE,
            'condition'     => [
                'profile_card_style' => [
                    'profile-card-style-1',
                    'profile-card-style-2',
                    'profile-card-style-3',
                    'profile-card-style-4',
                    'profile-card-style-5',
                    'profile-card-style-6',
                    'profile-card-style-7',
                    'profile-card-style-8',
                    'profile-card-style-9',
                    'profile-card-style-10',
                    'profile-card-style-11'
                ],
            ],
                ]
        );

        $this->add_control(
                'content_background_color', [
            'label'         => esc_html__('Background Color', CEPE_DOMAIN),
            'type'          => Controls_Manager::COLOR,
            'selectors'     => [
                '{{WRAPPER}} .elementor-content-background-color-wrapper' => 'background-color: {{VALUE}};',
            ],
                ]
        );

        $this->end_controls_section();


        /*
         * Start social media control style
         */
        $this->start_controls_section(
                'section_social_style', [
            'label'         => esc_html__('Social Icon', CEPE_DOMAIN),
            'tab'           => Controls_Manager::TAB_STYLE,
                ]
        );

        $this->add_control(
                'content_social_background_color', [
            'label'         => esc_html__('Social Area Background Color', CEPE_DOMAIN),
            'type'          => Controls_Manager::COLOR,
            'condition'     => [
                'profile_card_style' => ['profile-card-style-1', 'profile-card-style-2', 'profile-card-style-11'],
            ],
            'selectors'     => [
                '{{WRAPPER}} .team-member__socialmedia' => 'background-color: {{VALUE}};',
            ],
                ]
        );

        $this->add_control(
                'icon_color', [
            'label'         => esc_html__('Social Color', CEPE_DOMAIN),
            'type'          => Controls_Manager::SELECT,
            'default'       => 'default',
            'options'       => [
                'default'   => esc_html__('Official Color', CEPE_DOMAIN),
                'custom'    => esc_html__('Custom', CEPE_DOMAIN),
            ],
                ]
        );

        $this->add_control(
                'icon_primary_color', [
            'label'         => esc_html__('Primary Color', CEPE_DOMAIN),
            'type'          => Controls_Manager::COLOR,
            'condition'     => [
                'icon_color' => 'custom',
            ],
            'selectors'     => [
                '{{WRAPPER}} .elementor-social-icon:not(:hover)' => 'background-color: {{VALUE}};',
            ],
                ]
        );

        $this->add_control(
                'icon_secondary_color', [
            'label'         => esc_html__('Secondary Color', CEPE_DOMAIN),
            'type'          => Controls_Manager::COLOR,
            'condition'     => [
                'icon_color' => 'custom',
            ],
            'selectors'     => [
                '{{WRAPPER}} .elementor-social-icon:not(:hover) i' => 'color: {{VALUE}};',
            ],
                ]
        );

        $this->add_responsive_control(
                'icon_size', [
            'label'         => esc_html__('Size', CEPE_DOMAIN),
            'type'          => Controls_Manager::SLIDER,
            'range'         => [
                'px' => [
                    'min'   => 6,
                    'max'   => 300,
                ],
            ],
            'selectors'     => [
                '{{WRAPPER}} .elementor-social-icon' => 'font-size: {{SIZE}}{{UNIT}};',
            ],
                ]
        );

        $this->add_responsive_control(
                'icon_padding', [
            'label'         => esc_html__('Padding', CEPE_DOMAIN),
            'type'          => Controls_Manager::SLIDER,
            'selectors'     => [
                '{{WRAPPER}} .elementor-social-icon' => 'padding: {{SIZE}}{{UNIT}};',
            ],
            'default'       => [
                'unit' => 'em',
            ],
            'tablet_default' => [
                'unit' => 'em',
            ],
            'mobile_default' => [
                'unit' => 'em',
            ],
            'range'     => [
                'em' => [
                    'min' => 0,
                    'max' => 5,
                ],
            ],
                ]
        );

        $icon_spacing = is_rtl() ? 'margin-left: {{SIZE}}{{UNIT}};' : 'margin-right: {{SIZE}}{{UNIT}};';

        $this->add_responsive_control(
                'icon_spacing', [
            'label'         => esc_html__('Spacing', CEPE_DOMAIN),
            'type'          => Controls_Manager::SLIDER,
            'range'         => [
                'px' => [
                    'min'   => 0,
                    'max'   => 100,
                ],
            ],
            'selectors'     => [
                '{{WRAPPER}} .elementor-social-icon' => 'margin-right: {{SIZE}}{{UNIT}}!important;',
            ],
                ]
        );

        $this->add_group_control(
                Group_Control_Border::get_type(), [
            'name'          => 'image_border', // We know this mistake - TODO: 'icon_border' (for hover control condition also)
            'selector'      => '{{WRAPPER}} .elementor-social-icon',
            'separator'     => 'before',
                ]
        );

        $this->add_control(
                'border_radius', [
            'label'         => esc_html__('Border Radius', CEPE_DOMAIN),
            'type'          => Controls_Manager::DIMENSIONS,
            'size_units'    => ['px', '%'],
            'selectors'     => [
                '{{WRAPPER}} .elementor-icon' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
            ],
                ]
        );

        $this->end_controls_section();


        /*
         * Start social media hover control style
         */
        $this->start_controls_section(
                'section_social_hover', [
            'label'         => esc_html__('Social Icon Hover', CEPE_DOMAIN),
            'tab'           => Controls_Manager::TAB_STYLE,
                ]
        );

        $this->add_control(
                'hover_primary_color', [
            'label'         => esc_html__('Primary Color', CEPE_DOMAIN),
            'type'          => Controls_Manager::COLOR,
            'default'       => '',
            'condition'     => [
                'icon_color' => 'custom',
            ],
            'selectors'     => [
                '{{WRAPPER}} .elementor-social-icon:hover' => 'background-color: {{VALUE}};',
            ],
                ]
        );

        $this->add_control(
                'hover_secondary_color', [
            'label'         => esc_html__('Secondary Color', CEPE_DOMAIN),
            'type'          => Controls_Manager::COLOR,
            'default'       => '',
            'condition'     => [
                'icon_color' => 'custom',
            ],
            'selectors'     => [
                '{{WRAPPER}} .elementor-social-icon:hover i' => 'color: {{VALUE}};',
            ],
                ]
        );

        $this->add_control(
                'hover_border_color', [
            'label'         => esc_html__('Border Color', CEPE_DOMAIN),
            'type'          => Controls_Manager::COLOR,
            'default'       => '',
            'condition'     => [
                'image_border_border!' => '',
            ],
            'selectors'     => [
                '{{WRAPPER}} .elementor-social-icon:hover' => 'border-color: {{VALUE}};',
            ],
                ]
        );

        $this->add_control(
                'hover_animation', [
            'label'         => esc_html__('Hover Animation', CEPE_DOMAIN),
            'type'          => Controls_Manager::HOVER_ANIMATION,
                ]
        );

        $this->end_controls_section();

        /* start section for style 11 */
        $this->start_controls_section(
                'section_background_style', [
            'label'         => esc_html__('Content Background Color', CEPE_DOMAIN),
            'tab'           => Controls_Manager::TAB_STYLE,
            'condition'     => [
                'profile_card_style' => [
                    'profile-card-style-11'
                ]
            ]
                ]
        );

        $this->add_control(
                'name_background_color', [
            'label'         => esc_html__('Name', CEPE_DOMAIN),
            'type'          => Controls_Manager::COLOR,
            'selectors'     => [
                '{{WRAPPER}} .profile-card-style-11 .name' => 'background-color: {{VALUE}};',
            ],
                ]
        );

        $this->add_control(
                'position_background_color', [
            'label'         => esc_html__('Position', CEPE_DOMAIN),
            'type'          => Controls_Manager::COLOR,
            'selectors'     => [
                '{{WRAPPER}} .profile-card-style-11 .position' => 'background-color: {{VALUE}};',
            ],
                ]
        );

        $this->add_control(
                'description_background_color', [
            'label'         => esc_html__('Position', CEPE_DOMAIN),
            'type'          => Controls_Manager::COLOR,
            'selectors'     => [
                '{{WRAPPER}} .profile-card-style-11 .description' => 'background-color: {{VALUE}};',
            ],
                ]
        );

        $this->end_controls_section();


        $this->start_controls_section(
                'triangle_background_style', [
            'label'         => esc_html__('Triangle Color', CEPE_DOMAIN),
            'tab'           => Controls_Manager::TAB_STYLE,
            'condition'     => [
                'profile_card_style' => [
                    'profile-card-style-11'
                ]
            ]
                ]
        );

        $this->add_control(
                'triangle_background_color', [
            'label'         => esc_html__('Color', CEPE_DOMAIN),
            'type'          => Controls_Manager::COLOR,
            'selectors'     => [
                '{{WRAPPER}} .profile-card-style-11 .triangle-div' => 'border-top: solid 30px {{VALUE}}; border-left: solid 30px {{VALUE}};',
            ],
                ]
        );

        $this->end_controls_section();
        /*
         * End control style tab for profile card
         */
    }

    /**
     * Render Card Elements widget output on the front-end.
     *
     * Written in PHP and used to generate the final HTML.
     *
     * @access protected
     */
    protected function render() {

        $settings = $this->get_settings_for_display();

        $args = array(
            'blog_id'       => $GLOBALS['blog_id'],
            'role'          => '',
            'role__in'      => array(),
            'role__not_in'  => array(),
            'meta_key'      => '',
            'meta_value'    => '',
            'meta_compare'  => '',
            'meta_query'    => array(),
            'date_query'    => array(),
            'include'       => array(),
            'exclude'       => array(),
            'orderby'       => 'login',
            'order'         => 'ASC',
            'offset'        => '',
            'search'        => '',
            'number'        => '',
            'count_total'   => false,
            'fields'        => 'all',
            'who'           => '',
        );
        $data = get_users($args);

        $class_animation = '';

        if (!empty($settings['hover_animation'])) {
            $class_animation = ' elementor-animation-' . $settings['hover_animation'];
        }

        switch ($settings['profile_card_style']) {
            case 'profile-card-style-1':
                include CEPE_PATH . 'include/profile-card/elementor-profile-card-1.php';  // Card Style 1
                break;
            case 'profile-card-style-2':
                include CEPE_PATH . 'include/profile-card/elementor-profile-card-2.php';  // Card Style 2
                break;
            case 'profile-card-style-3':
                include CEPE_PATH . 'include/profile-card/elementor-profile-card-3.php';  // Card Style 3
                break;
            case 'profile-card-style-4':
                include CEPE_PATH . 'include/profile-card/elementor-profile-card-4.php';  // Card Style 4
                break;
            case 'profile-card-style-5':
                include CEPE_PATH . 'include/profile-card/elementor-profile-card-5.php';  // Card Style 5
                break;
            case 'profile-card-style-6':
                include CEPE_PATH . 'include/profile-card/elementor-profile-card-6.php';  //  Card Style 6
                break;
            case 'profile-card-style-7':
                include CEPE_PATH . 'include/profile-card/elementor-profile-card-7.php';  //  Card Style 7
                break;
            case 'profile-card-style-8':
                include CEPE_PATH . 'include/profile-card/elementor-profile-card-8.php';  //  Card Style 8
                break;
            case 'profile-card-style-9':
                include CEPE_PATH . 'include/profile-card/elementor-profile-card-9.php';  //  Card Style 9
                break;
            case 'profile-card-style-10':
                include CEPE_PATH . 'include/profile-card/elementor-profile-card-10.php';  //  Card Style 10
                break;
            case 'profile-card-style-11':
                include CEPE_PATH . 'include/profile-card/elementor-profile-card-11.php';  //  Card Style 11
                break;
            default:
                include CEPE_PATH . 'include/profile-card/elementor-profile-card-1.php';  // Default Card Style
                break;
        }
    }

}

Plugin::instance()->widgets_manager->register_widget_type(new Cep_Profile_Card_Pro_Elementor_Widget());