<?php

namespace Elementor;

if (!defined('ABSPATH'))
    exit;      // Exit if accessed directly

class Cep_Recipe_Card_Pro_Elementor_Widget extends Widget_Base {

    //Function for get the slug of the element name.
    public function get_name() {
        return 'recipe-card-elementor-widget';
    }

    //Function for get the name of the element.
    public function get_title() {
        return __('Recipe Card', CEPE_DOMAIN);
    }

    //Function for get the icon of the element.
    public function get_icon() {
        return 'fas fa-utensils';
    }

    //Function for include element into the category.
    public function get_categories() {
        return ['card-elements'];
    }

    protected function _register_controls() {

        /*
         * Start recipe card controls fields
         */
        $this->start_controls_section(
                'section_items_data', array(
            'label' => esc_html__('Recipe Card Items', CEPE_DOMAIN),
                )
        );


        $this->add_control(
                'recipe_card_style', [
            'label' => __('Recipe Card Style', CEPE_DOMAIN),
            'type' => Controls_Manager::SELECT,
            'options' => [
                'recipe-card-style-1' => esc_html__('Card Style 1', CEPE_DOMAIN),
                'recipe-card-style-2' => esc_html__('Card Style 2', CEPE_DOMAIN),
                'recipe-card-style-3' => esc_html__('Card Style 3', CEPE_DOMAIN),
                'recipe-card-style-4' => esc_html__('Card Style 4', CEPE_DOMAIN),
                'recipe-card-style-5' => esc_html__('Card Style 5', CEPE_DOMAIN),
            ],
            'default' => 'recipe-card-style-1',
                ]
        );

        $this->add_control(
                'dish_name', [
            'label' => __('Name', CEPE_DOMAIN),
            'type' => Controls_Manager::TEXT,
            'default' => __('Ice Cream', CEPE_DOMAIN),
            'placeholder' => __('Write Dish Name', CEPE_DOMAIN),
                ]
        );

        $this->add_control(
                'dish_type', [
            'label' => __('Type', CEPE_DOMAIN),
            'type' => Controls_Manager::TEXT,
            'default' => __('Dessert', CEPE_DOMAIN),
            'placeholder' => __('Write Type', CEPE_DOMAIN),
                ]
        );

        $this->add_control(
                'dish_image', [
            'label' => __('Image', CEPE_DOMAIN),
            'type' => Controls_Manager::MEDIA,
            'dynamic' => [
                'active' => true,
            ],
            'default' => [
                'url' => Utils::get_placeholder_image_src(),
            ],
                ]
        );

        $this->add_control(
                'image_background_overlay', [
            'label' => __('Background Overlay', CEPE_DOMAIN),
            'type' => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .recipe-card-style-1 .recipe-img-overlay,
		{{WRAPPER}} .recipe-card-style-2 .recipe-img-overlay,
		{{WRAPPER}} .recipe-card-style-3 .recipe-img-overlay,
		{{WRAPPER}} .recipe-card-style-4 .recipe-img-overlay,
		{{WRAPPER}} .recipe-card-style-5 .recipe-img-overlay' => 'background-color: {{VALUE}};',
            ],
                ]
        );

        $this->add_control(
                'recipe_whatsapp_share', [
            'label' => __('Whatsapp Share', CEPE_DOMAIN),
            'type' => Controls_Manager::SWITCHER,
            'default' => 'yes',
            'label_on' => __('Show', CEPE_DOMAIN),
            'label_off' => __('Hide', CEPE_DOMAIN),
                ]
        );

        $this->add_control(
                'display_recipe_description', [
            'label' => __('Display Recipe Description', CEPE_DOMAIN),
            'type' => Controls_Manager::SWITCHER,
            'default' => 'yes',
            'label_on' => __('Show', CEPE_DOMAIN),
            'label_off' => __('Hide', CEPE_DOMAIN),
                ]
        );

        $this->add_control(
                'recipe_description', array(
            'label' => esc_html__('Description', CEPE_DOMAIN),
            'type' => Controls_Manager::TEXTAREA,
            'condition' => [
                'display_recipe_description' => 'yes',
            ],
            'default' => __('Lorem ipsum dolor sit amet, consectetur adipisci ng elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.', CEPE_DOMAIN),
                )
        );

        $this->end_controls_section();

        $this->start_controls_section(
                'section_items_details_data', array(
            'label' => esc_html__('Details', CEPE_DOMAIN),
                )
        );

        $this->add_control(
                'recipe_label_1', [
            'label' => __('Label 1', CEPE_DOMAIN),
            'type' => Controls_Manager::TEXT,
            'default' => __('min.', CEPE_DOMAIN),
                ]
        );

        $this->add_control(
                'recipe_value_1', array(
            'label' => esc_html__('Value 1', CEPE_DOMAIN),
            'default' => __('10', CEPE_DOMAIN),
            'type' => Controls_Manager::NUMBER,
                )
        );

        $this->add_control(
                'recipe_label_2', [
            'label' => __('Label 2', CEPE_DOMAIN),
            'type' => Controls_Manager::TEXT,
            'default' => __('serv.', CEPE_DOMAIN),
            'separator' => 'before',
                ]
        );

        $this->add_control(
                'recipe_value_2', array(
            'label' => esc_html__('Value 2', CEPE_DOMAIN),
            'type' => Controls_Manager::NUMBER,
            'default' => __('3', CEPE_DOMAIN),
                )
        );

        $this->add_control(
                'recipe_label_3', [
            'label' => __('Label 3', CEPE_DOMAIN),
            'type' => Controls_Manager::TEXT,
            'default' => __('ing.', CEPE_DOMAIN),
            'separator' => 'before',
                ]
        );

        $this->add_control(
                'recipe_value_3', array(
            'label' => esc_html__('Value 3', CEPE_DOMAIN),
            'default' => __('6', CEPE_DOMAIN),
            'type' => Controls_Manager::NUMBER,
                )
        );

        $this->add_control(
                'recipe_minutes', array(
            'label' => esc_html__('Minutes', CEPE_DOMAIN),
            'type' => Controls_Manager::NUMBER,
                )
        );

        $this->add_control(
                'recipe_servings', array(
            'label' => esc_html__('Servings', CEPE_DOMAIN),
            'type' => Controls_Manager::NUMBER,
                )
        );

        $this->add_control(
                'recipe_ingredients', array(
            'label' => esc_html__('Ingredients', CEPE_DOMAIN),
            'type' => Controls_Manager::NUMBER,
                )
        );

        $this->end_controls_section();

        $this->start_controls_section(
                'section_button_data', array(
            'label' => esc_html__('Button', CEPE_DOMAIN),
                )
        );

        $this->add_control(
                'button_text', [
            'label' => __('Button Text', CEPE_DOMAIN),
            'type' => Controls_Manager::TEXT,
            'default' => __('View Recipe', CEPE_DOMAIN),
            'placeholder' => __('Button text', CEPE_DOMAIN),
                ]
        );

        $this->add_control(
                'recipe_btn_link', [
            'label' => esc_html__('URL (Link)', CEPE_DOMAIN),
            'type' => \Elementor\Controls_Manager::URL,
            'show_external' => true,
            'default' => [
                'url' => '',
                'is_external' => true,
                'nofollow' => true,
            ],
                ]
        );

        $this->end_controls_section();
        /*
         * End recipe card controls fields
         */

        /*
         * Start control style tab for recipe card
         * Start name control style
         */
        $this->start_controls_section(
                'section_recipe_name', [
            'label' => __('Name', CEPE_DOMAIN),
            'tab' => Controls_Manager::TAB_STYLE,
                ]
        );

        $this->add_responsive_control(
                'name_text_align', [
            'label' => __('Alignment', CEPE_DOMAIN),
            'type' => Controls_Manager::CHOOSE,
            'options' => [
                'left' => [
                    'title' => __('Left', CEPE_DOMAIN),
                    'icon' => 'eicon-text-align-left',
                ],
                'center' => [
                    'title' => __('Center', CEPE_DOMAIN),
                    'icon' => 'eicon-text-align-center',
                ],
                'right' => [
                    'title' => __('Right', CEPE_DOMAIN),
                    'icon' => 'eicon-text-align-right',
                ],
                'justify' => [
                    'title' => __('Justified', CEPE_DOMAIN),
                    'icon' => 'eicon-text-align-justify',
                ],
            ],
            'selectors' => [
                '{{WRAPPER}} .elementor-recipe-name-wrapper' => 'text-align: {{VALUE}};',
            ],
                ]
        );

        $this->add_control(
                'name_color', [
            'label' => __('Text Color', CEPE_DOMAIN),
            'type' => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .elementor-recipe-name-wrapper' => 'color: {{VALUE}};',
            ],
                ]
        );

        $this->add_group_control(
                Group_Control_Typography::get_type(), [
            'name' => 'typography_name',
            'selector' => '{{WRAPPER}} .elementor-recipe-name-wrapper',
                ]
        );


        $this->add_group_control(
                Group_Control_Border::get_type(), [
            'name' => 'recipe_name_border',
            'selector' => '{{WRAPPER}} .elementor-recipe-name-wrapper',
            'separator' => 'before',
                ]
        );

        $this->add_control(
                'recipe_button_border_radius', [
            'label' => __('Border Radius', CEPE_DOMAIN),
            'type' => Controls_Manager::DIMENSIONS,
            'size_units' => ['px', '%'],
            'selectors' => [
                '{{WRAPPER}} .elementor-recipe-name-wrapper' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
            ],
                ]
        );

        $this->add_control(
                'name_spacing', [
            'label' => __('Spacing', CEPE_DOMAIN),
            'type' => Controls_Manager::SLIDER,
            'range' => [
                'px' => [
                    'max' => 100,
                ],
            ],
            'selectors' => [
                '{{WRAPPER}} .elementor-recipe-name-wrapper' => 'margin-bottom: {{SIZE}}{{UNIT}};',
            ],
                ]
        );

        $this->end_controls_section();

        /*
         * Start type control style
         */
        $this->start_controls_section(
                'section_recipe_type', [
            'label' => __('Type', CEPE_DOMAIN),
            'tab' => Controls_Manager::TAB_STYLE,
                ]
        );

        $this->add_responsive_control(
                'type_text_align', [
            'label' => __('Alignment', CEPE_DOMAIN),
            'type' => Controls_Manager::CHOOSE,
            'options' => [
                'left' => [
                    'title' => __('Left', CEPE_DOMAIN),
                    'icon' => 'eicon-text-align-left',
                ],
                'center' => [
                    'title' => __('Center', CEPE_DOMAIN),
                    'icon' => 'eicon-text-align-center',
                ],
                'right' => [
                    'title' => __('Right', CEPE_DOMAIN),
                    'icon' => 'eicon-text-align-right',
                ],
                'justify' => [
                    'title' => __('Justified', CEPE_DOMAIN),
                    'icon' => 'eicon-text-align-justify',
                ],
            ],
            'selectors' => [
                '{{WRAPPER}} .elementor-recipe-type-wrapper' => 'text-align: {{VALUE}};',
            ],
                ]
        );

        $this->add_control(
                'position_color', [
            'label' => __('Text Color', CEPE_DOMAIN),
            'type' => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .elementor-recipe-type-wrapper' => 'color: {{VALUE}};',
            ],
                ]
        );

        $this->add_group_control(
                Group_Control_Typography::get_type(), [
            'name' => 'typography_position',
            'selector' => '{{WRAPPER}} .elementor-recipe-type-wrapper',
                ]
        );

        $this->add_control(
                'type_spacing', [
            'label' => __('Spacing', CEPE_DOMAIN),
            'type' => Controls_Manager::SLIDER,
            'condition' => [
                'recipe_card_style' => ['recipe-card-style-1', 'recipe-card-style-2'],
            ],
            'range' => [
                'px' => [
                    'max' => 100,
                ],
            ],
            'selectors' => [
                '{{WRAPPER}} .elementor-recipe-type-wrapper' => 'margin-bottom: {{SIZE}}{{UNIT}};',
            ],
                ]
        );

        $this->add_control(
                'types_background_color', [
            'label' => __('Background Color', CEPE_DOMAIN),
            'type' => Controls_Manager::COLOR,
            'condition' => [
                'recipe_card_style' => ['recipe-card-style-3'],
            ],
            'selectors' => [
                '{{WRAPPER}} .bg-color-type' => 'background: {{VALUE}};',
            ],
                ]
        );

        $this->add_control(
                'separator_color', [
            'label' => __('Separator Color', CEPE_DOMAIN),
            'type' => Controls_Manager::COLOR,
            'condition' => [
                'recipe_card_style' => ['recipe-card-style-1', 'recipe-card-style-2'],
            ],
            'selectors' => [
                '{{WRAPPER}} .recipe-content' => ' border-bottom-color: {{VALUE}};',
            ],
                ]
        );

        $this->add_control(
                'separator_spacing', [
            'label' => __('Separator Spacing', CEPE_DOMAIN),
            'type' => Controls_Manager::SLIDER,
            'condition' => [
                'recipe_card_style' => ['recipe-card-style-1', 'recipe-card-style-2'],
            ],
            'range' => [
                'px' => [
                    'max' => 100,
                ],
            ],
            'selectors' => [
                '{{WRAPPER}} .recipe-detail' => 'padding-top: {{SIZE}}{{UNIT}};',
            ],
                ]
        );

        $this->end_controls_section();

        /*
         * Start details control style
         */
        $this->start_controls_section(
                'section_recipe_details', [
            'label' => __('Details', CEPE_DOMAIN),
            'tab' => Controls_Manager::TAB_STYLE,
                ]
        );

        $this->add_responsive_control(
                'details_text_align', [
            'label' => __('Alignment', CEPE_DOMAIN),
            'type' => Controls_Manager::CHOOSE,
            'condition' => [
                'recipe_card_style' => ['recipe-card-style-1', 'recipe-card-style-2'],
            ],
            'options' => [
                '		left' => [
                    'title' => __('Left', CEPE_DOMAIN),
                    'icon' => 'eicon-text-align-left',
                ],
                'center' => [
                    'title' => __('Center', CEPE_DOMAIN),
                    'icon' => 'eicon-text-align-center',
                ],
                'right' => [
                    'title' => __('Right', CEPE_DOMAIN),
                    'icon' => 'eicon-text-align-right',
                ],
                'justify' => [
                    'title' => __('Justified', CEPE_DOMAIN),
                    'icon' => 'eicon-text-align-justify',
                ],
            ],
            'selectors' => [
                '{{WRAPPER}} .recipe-detail' => 'text-align: {{VALUE}};',
            ],
                ]
        );

        $this->add_control(
                'detail_no_spacing', [
            'label' => __('Gap', CEPE_DOMAIN),
            'type' => Controls_Manager::SLIDER,
            'condition' => [
                'recipe_card_style' => ['recipe-card-style-2'],
            ],
            'range' => [
                'px' => [
                    'max' => 100,
                ],
            ],
            'selectors' => [
                '{{WRAPPER}} .recipe-detail-no' => 'margin-right: {{SIZE}}{{UNIT}};',
            ],
                ]
        );

        $this->add_control(
                'qty_color', [
            'label' => __('Qty Color', CEPE_DOMAIN),
            'type' => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .recipe-detail-no' => 'color: {{VALUE}};',
            ],
                ]
        );

        $this->add_group_control(
                Group_Control_Typography::get_type(), [
            'name' => 'typography_Qty',
            'selector' => '{{WRAPPER}} .recipe-detail-no',
                ]
        );

        $this->add_control(
                'details_text_color', [
            'label' => __('Text Color', CEPE_DOMAIN),
            'type' => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .recipe-detail-text' => 'color: {{VALUE}};',
            ],
                ]
        );

        $this->add_group_control(
                Group_Control_Typography::get_type(), [
            'name' => 'typography_detais_text',
            'selector' => '{{WRAPPER}} .recipe-detail-text',
                ]
        );

        $this->add_control(
                'details_background_color', [
            'label' => __('Background Color', CEPE_DOMAIN),
            'type' => Controls_Manager::COLOR,
            'condition' => [
                'recipe_card_style' => ['recipe-card-style-3'],
            ],
            'selectors' => [
                '{{WRAPPER}} .bg-color' => 'background: {{VALUE}};',
            ],
                ]
        );

        $this->add_control(
                'detail_spacing', [
            'label' => __('Spacing', CEPE_DOMAIN),
            'type' => Controls_Manager::SLIDER,
            'condition' => [
                'recipe_card_style' => ['recipe-card-style-1', 'recipe-card-style-2'],
            ],
            'range' => [
                'px' => [
                    'max' => 100,
                ],
            ],
            'selectors' => [
                '{{WRAPPER}} .recipe-detail' => 'padding-bottom: {{SIZE}}{{UNIT}};',
            ],
                ]
        );

        $this->end_controls_section();

        /*
         * Start desription control style
         */
        $this->start_controls_section(
                'section_recipe_description', [
            'label' => __('Description', CEPE_DOMAIN),
            'tab' => Controls_Manager::TAB_STYLE,
                ]
        );

        $this->add_responsive_control(
                'description_text_align', [
            'label' => __('Alignment', CEPE_DOMAIN),
            'type' => Controls_Manager::CHOOSE,
            'options' => [
                'left' => [
                    'title' => __('Left', CEPE_DOMAIN),
                    'icon' => 'eicon-text-align-left',
                ],
                'center' => [
                    'title' => __('Center', CEPE_DOMAIN),
                    'icon' => 'eicon-text-align-center',
                ],
                'right' => [
                    'title' => __('Right', CEPE_DOMAIN),
                    'icon' => 'eicon-text-align-right',
                ],
                'justify' => [
                    'title' => __('Justified', CEPE_DOMAIN),
                    'icon' => 'eicon-text-align-justify',
                ],
            ],
            'selectors' => [
                '{{WRAPPER}} .elementor-recipe-description-wrapper' => 'text-align: {{VALUE}};',
            ],
                ]
        );

        $this->add_control(
                'description_color', [
            'label' => __('Text Color', CEPE_DOMAIN),
            'type' => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .elementor-recipe-description-wrapper' => 'color: {{VALUE}};',
            ],
                ]
        );

        $this->add_group_control(
                Group_Control_Typography::get_type(), [
            'name' => 'typography_description',
            'selector' => '{{WRAPPER}} .elementor-recipe-description-wrapper',
                ]
        );

        $this->add_control(
                'description_spacing', [
            'label' => __('Spacing', CEPE_DOMAIN),
            'type' => Controls_Manager::SLIDER,
            'range' => [
                'px' => [
                    'max' => 100,
                ],
            ],
            'selectors' => [
                '{{WRAPPER}} .elementor-recipe-description-wrapper' => 'margin-bottom: {{SIZE}}{{UNIT}};',
            ],
                ]
        );

        $this->end_controls_section();

        /*
         * Start control style tab for recipe card
         * Start button control style
         */
        $this->start_controls_section(
                'section_style', [
            'label' => __('Button', CEPE_DOMAIN),
            'tab' => Controls_Manager::TAB_STYLE,
                ]
        );

        $this->add_responsive_control(
                'button_text_align', [
            'label' => __('Alignment', CEPE_DOMAIN),
            'type' => Controls_Manager::CHOOSE,
            'options' => [
                'left' => [
                    'title' => __('Left', CEPE_DOMAIN),
                    'icon' => 'eicon-text-align-left',
                ],
                'center' => [
                    'title' => __('Center', CEPE_DOMAIN),
                    'icon' => 'eicon-text-align-center',
                ],
                'right' => [
                    'title' => __('Right', CEPE_DOMAIN),
                    'icon' => 'eicon-text-align-center',
                ],
                'justify' => [
                    'title' => __('Justified', CEPE_DOMAIN),
                    'icon' => 'eicon-text-align-center',
                ],
            ],
            'selectors' => [
                '{{WRAPPER}} .recipe-button' => 'text-align: {{VALUE}};',
            ],
                ]
        );

        $this->add_group_control(
                Group_Control_Typography::get_type(), [
            'name' => 'typography',
            'selector' => '{{WRAPPER}} .recipe-button a',
                ]
        );

        $this->start_controls_tabs('tabs_button_style');

        $this->start_controls_tab(
                'tab_button_normal', [
            'label' => __('Normal', CEPE_DOMAIN),
                ]
        );

        $this->add_control(
                'recipe_button_text_color', [
            'label' => __('Text Color', CEPE_DOMAIN),
            'type' => Controls_Manager::COLOR,
            'default' => '',
            'selectors' => [
                '{{WRAPPER}} .recipe-button a' => 'color: {{VALUE}};',
            ],
                ]
        );

        $this->add_control(
                'background_color', [
            'label' => __('Background Color', CEPE_DOMAIN),
            'type' => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .recipe-button a' => 'background-color: {{VALUE}};',
            ],
                ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
                'tab_button_hover', [
            'label' => __('Hover', CEPE_DOMAIN),
                ]
        );

        $this->add_control(
                'recipe_text_hover_color', [
            'label' => __('Text Color', CEPE_DOMAIN),
            'type' => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .recipe-button a:hover' => 'color: {{VALUE}};',
            ],
                ]
        );

        $this->add_control(
                'recipe_button_background_hover_color', [
            'label' => __('Background Color', CEPE_DOMAIN),
            'type' => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .recipe-button a:hover' => 'background-color: {{VALUE}};',
            ],
                ]
        );

        $this->add_control(
                'recpipe_button_hover_border_color', [
            'label' => __('Border Color', CEPE_DOMAIN),
            'type' => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .recipe-button a:hover' => 'border-color: {{VALUE}};',
            ],
                ]
        );

        $this->end_controls_tabs();

        $this->add_group_control(
                Group_Control_Border::get_type(), [
            'name' => 'border',
            'selector' => '{{WRAPPER}} .recipe-button a',
            'separator' => 'before',
                ]
        );

        $this->add_control(
                'reipe_button_border_radius', [
            'label' => __('Border Radius', CEPE_DOMAIN),
            'type' => Controls_Manager::DIMENSIONS,
            'size_units' => ['px', '%'],
            'selectors' => [
                '{{WRAPPER}} .recipe-button a' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
            ],
                ]
        );

        $this->add_group_control(
                Group_Control_Box_Shadow::get_type(), [
            'name' => 'button_box_shadow',
            'selector' => '{{WRAPPER}} .recipe-button a',
                ]
        );

        $this->add_responsive_control(
                'text_padding', [
            'label' => __('Padding', CEPE_DOMAIN),
            'type' => Controls_Manager::DIMENSIONS,
            'size_units' => ['px', 'em', '%'],
            'selectors' => [
                '{{WRAPPER}} .recipe-button a' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
            ],
            'separator' => 'before',
                ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
                'section_recipe_contentbox', [
            'label' => __('Box', CEPE_DOMAIN),
            'tab' => Controls_Manager::TAB_STYLE,
                ]
        );

        $this->add_responsive_control(
                'box_padding', [
            'label' => __('Padding', CEPE_DOMAIN),
            'type' => Controls_Manager::DIMENSIONS,
            'size_units' => ['px', '%'],
            'devices' => ['desktop', 'tablet', 'mobile'],
            'selectors' => [
                '{{WRAPPER}} .recipe-card-style-1 .recipe-container,
		{{WRAPPER}} .recipe-card-style-2 .recipe-main-container,
		{{WRAPPER}} .recipe-card-style-3 .recipe-content,
		{{WRAPPER}} .recipe-card-style-4 .recipe-container,
		{{WRAPPER}} .recipe-card-style-5 .recipe-left,
		{{WRAPPER}} .recipe-card-style-5 .recipe-right' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
            ],
                ]
        );

        $this->add_control(
                'button_box_background_color', [
            'label' => __('Background Color', CEPE_DOMAIN),
            'type' => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .recipe-card-style-1 .recipe-main-container,
		{{WRAPPER}} .recipe-card-style-2 .recipe-main-container,
		{{WRAPPER}} .recipe-card-style-3 .recipe-content,
		{{WRAPPER}} .recipe-card-style-5 .recipe-main-container' => 'background-color: {{VALUE}};',
            ],
                ]
        );

        $this->add_group_control(
                Group_Control_Border::get_type(), [
            'name' => 'image_border',
            'selector' => '{{WRAPPER}} .recipe-card-style-1,
			   {{WRAPPER}} .recipe-card-style-2,
			   {{WRAPPER}} .recipe-card-style-3,
			   {{WRAPPER}} .recipe-card-style-4,
			   {{WRAPPER}} .recipe-card-style-5',
            'separator' => 'before',
                ]
        );

        $this->add_responsive_control(
                'border_radius', [
            'label' => __('Border Radius', CEPE_DOMAIN),
            'type' => Controls_Manager::DIMENSIONS,
            'size_units' => ['px', '%'],
            'devices' => ['desktop', 'tablet', 'mobile'],
            'selectors' => [
                '{{WRAPPER}} .recipe-card-style-1,
		{{WRAPPER}} .recipe-card-style-2,
		{{WRAPPER}} .recipe-card-style-3,
		{{WRAPPER}} .recipe-card-style-4,
		{{WRAPPER}} .recipe-card-style-5' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
            ],
                ]
        );

        $this->end_controls_section();

        /*
         * End control style tab for recipe card
         */
    }

    /**
     * Render recipe card widget output on the front-end.
     *
     * Written in PHP and used to generate the final HTML.
     *
     * @access protected
     */
    protected function render() {

        $settings = $this->get_settings_for_display();

        $recipe_btn_link = $settings['recipe_btn_link'];
        $target = $settings['recipe_btn_link']['is_external'] ? ' target="_blank"' : '';
        $rel = $settings['recipe_btn_link']['nofollow'] ? ' rel="nofollow"' : '';

        switch ($settings['recipe_card_style']) {
            case 'recipe-card-style-1':
                include CEPE_PATH . 'include/recipe-card/elementor-recipe-card-1.php';  // Card Style 1
                break;
            case 'recipe-card-style-2':
                include CEPE_PATH . 'include/recipe-card/elementor-recipe-card-2.php';  // Card Style 2
                break;
            case 'recipe-card-style-3':
                include CEPE_PATH . 'include/recipe-card/elementor-recipe-card-3.php';  // Card Style 3
                break;
            case 'recipe-card-style-4':
                include CEPE_PATH . 'include/recipe-card/elementor-recipe-card-4.php';  // Card Style 4
                break;
            case 'recipe-card-style-5':
                include CEPE_PATH . 'include/recipe-card/elementor-recipe-card-5.php';  // Card Style 5
                break;
            default:
                include CEPE_PATH . 'include/recipe-card/elementor-recipe-card-1.php';  // Default Card Style 1
                break;
        }
    }

}

Plugin::instance()->widgets_manager->register_widget_type(new Cep_Recipe_Card_Pro_Elementor_Widget());
