<?php

namespace Elementor;

if (!defined('ABSPATH'))
    exit;      // Exit if accessed directly

class Cep_Testimonial_Card_Pro_Elementor_Widget extends Widget_Base {

    //Function for get the slug of the element name.
    public function get_name() {
        return 'testimonial-card-elementor-widget';
    }

    //Function for get the name of the element.
    public function get_title() {
        return esc_html__('Testimonial Card', CEPE_DOMAIN);
    }

    //Function for get the icon of the element.
    public function get_icon() {
        return 'eicon-testimonial';
    }

    //Function for include element into the category.
    public function get_categories() {
        return ['card-elements'];
    }

    /*
     * Adding the controls fields for the testimonial card
     */

    protected function _register_controls() {

        /*
         * Start testimonial card controls fields
         */
        $this->start_controls_section(
                'section_items_data', array(
            'label' => esc_html__('Testimonial Card Items', CEPE_DOMAIN),
                )
        );

        $this->add_control(
                'cep_testimonial_type', [
            'label' => esc_html__('Select Resouce Type', CEPE_DOMAIN),
            'type' => Controls_Manager::SELECT,
            'options' => [
                'custom' => esc_html__('Custom', CEPE_DOMAIN),
                'post' => esc_html__('Post Type', CEPE_DOMAIN),
            ],
            'default' => 'custom',
                ]
        );
        $this->add_control(
                'cep_testimonial_type_post', [
            'label' => esc_html__('Select Post Type', CEPE_DOMAIN),
            'type' => Controls_Manager::SELECT,
            'options' => [
                'cep_testimonial' => esc_html__('CEP Testimonial', CEPE_DOMAIN),
            ],
            'condition' => ['cep_testimonial_type' => 'post'],
            'default' => 'cep_testimonial',
                ]
        );

        $this->add_control(
                'testimonial_card_style', [
            'label' => esc_html__('Testimonial Card Style', CEPE_DOMAIN),
            'type' => Controls_Manager::SELECT,
            'options' => [
                'testimonial-card-style-1' => esc_html__('Card Style 1', CEPE_DOMAIN),
                'testimonial-card-style-2' => esc_html__('Card Style 2', CEPE_DOMAIN),
                'testimonial-card-style-3' => esc_html__('Card Style 3', CEPE_DOMAIN),
                'testimonial-card-style-4' => esc_html__('Card Style 4', CEPE_DOMAIN),
                'testimonial-card-style-5' => esc_html__('Card Style 5', CEPE_DOMAIN),
                'testimonial-card-style-6' => esc_html__('Card Style 6', CEPE_DOMAIN),
            ],
            'default' => 'testimonial-card-style-1',
                ]
        );

        $this->add_responsive_control(
                'cept_card_columns', [
            'label' => esc_html__('Columns', CEPE_DOMAIN),
            'type' => Controls_Manager::SELECT,
            'default' => '3',
            'tablet_default' => '2',
            'mobile_default' => '1',
            'options' => [
                '1' => esc_html__('1', CEPE_DOMAIN),
                '2' => esc_html__('2', CEPE_DOMAIN),
                '3' => esc_html__('3', CEPE_DOMAIN),
                '4' => esc_html__('4', CEPE_DOMAIN),
                '5' => esc_html__('5', CEPE_DOMAIN),
                '6' => esc_html__('6', CEPE_DOMAIN),
            ],
            'prefix_class' => 'elementor-grid%s-',
            'frontend_available' => true,
            'condition' => ['cep_testimonial_type' => 'post'],
            'selectors' => [
                '.elementor-msie {{WRAPPER}} .elementor-post-item' => 'width: calc( 100% / {{SIZE}} )',
            ],
                ]
        );

        $this->add_control(
                'cept_number_of_posts', [
            'label' => esc_html__('Display No. of Posts', CEPE_DOMAIN),
            'type' => Controls_Manager::NUMBER,
            'condition' => ['cep_testimonial_type' => 'post'],
            'default' => 6,
                ]
        );

        $this->add_control(
                'name', [
            'label' => esc_html__('Name', CEPE_DOMAIN),
            'type' => Controls_Manager::TEXT,
            'default' => esc_html__('John Doe', CEPE_DOMAIN),
            'condition' => ['cep_testimonial_type' => 'custom'],
            'placeholder' => esc_html__('Enter your name', CEPE_DOMAIN),
                ]
        );

        $this->add_control(
                'position', [
            'label' => esc_html__('Designation', CEPE_DOMAIN),
            'type' => Controls_Manager::TEXT,
            'default' => esc_html__('Founder', CEPE_DOMAIN),
            'condition' => ['cep_testimonial_type' => 'custom'],
            'placeholder' => esc_html__('Founder', CEPE_DOMAIN),
                ]
        );

        $this->add_control(
                'display_testimonial_description', [
            'label' => esc_html__('Display Testimonial Description', CEPE_DOMAIN),
            'type' => Controls_Manager::SWITCHER,
            'default' => 'yes',
            'label_on' => esc_html__('Show', CEPE_DOMAIN),
            'label_off' => esc_html__('Hide', CEPE_DOMAIN),
                ]
        );

        $this->add_control(
                'testimonial_description', array(
            'label' => esc_html__('Description', CEPE_DOMAIN),
            'type' => Controls_Manager::TEXTAREA,
            'condition' => [
                'display_testimonial_description' => 'yes', 'cep_testimonial_type' => 'custom'
            ],
            'default' => esc_html__('Lorem ipsum dolor sit amet, consectetur adipisci ng elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.', CEPE_DOMAIN),
                )
        );

        $this->add_control(
                'profile_image', [
            'label' => esc_html__('Profile Image', CEPE_DOMAIN),
            'type' => Controls_Manager::MEDIA,
            'dynamic' => [
                'active' => true,
            ],
            'condition' => ['cep_testimonial_type' => 'custom'],
            'default' => [
                'url' => Utils::get_placeholder_image_src(),
            ],
                ]
        );

        $this->add_control(
                'profile_background_image', [
            'label' => esc_html__('Profile Background Image', CEPE_DOMAIN),
            'type' => Controls_Manager::MEDIA,
            'dynamic' => [
                'active' => true,
            ],
            'condition' => ['testimonial_card_style' => 'testimonial-card-style-6', 'cep_testimonial_type' => 'custom'
            ],
            'default' => [
                'url' => Utils::get_placeholder_image_src(),
            ],
                ]
        );

        $this->end_controls_section();
        /*
         * End testimonial card controls fields
         */
        $this->start_controls_section(
                'section_rating', [
            'label' => esc_html__('Rating', CEPE_DOMAIN),
            'condition' => [
                'testimonial_card_style' => ['testimonial-card-style-1'],
                'testimonial_card_style' => ['testimonial-card-style-2'],
            ],
                ]
        );

        $this->add_control(
                'display_testimonial_rating', [
            'label' => esc_html__('Display Rating', CEPE_DOMAIN),
            'type' => Controls_Manager::SWITCHER,
            'default' => 'yes',
            'label_on' => esc_html__('Show', CEPE_DOMAIN),
            'label_off' => esc_html__('Hide', CEPE_DOMAIN),
                ]
        );

        $this->add_control(
                'rating_scale', [
            'label' => esc_html__('Rating Scale', CEPE_DOMAIN),
            'type' => Controls_Manager::SELECT,
            'options' => [
                '5' => esc_html__('0-5', CEPE_DOMAIN),
                '10' => esc_html__('0-10', CEPE_DOMAIN),
            ],
            'condition' => ['cep_testimonial_type' => 'custom'],
            'default' => '5',
                ]
        );

        $this->add_control(
                'rating', [
            'label' => esc_html__('Rating', CEPE_DOMAIN),
            'type' => Controls_Manager::NUMBER,
            'min' => 0,
            'max' => 10,
            'step' => 0.1,
            'default' => 5,
            'condition' => ['cep_testimonial_type' => 'custom'],
                ]
        );

        $this->add_control(
                'star_style', [
            'label' => esc_html__('Icon', CEPE_DOMAIN),
            'type' => Controls_Manager::SELECT,
            'options' => [
                'star_fontawesome' => esc_html__('Font Awesome', CEPE_DOMAIN),
                'star_unicode' => esc_html__('Unicode', CEPE_DOMAIN),
            ],
            'default' => 'star_fontawesome',
            'render_type' => 'template',
            'prefix_class' => 'elementor--star-style-',
            'separator' => 'before',
            'condition' => ['cep_testimonial_type' => 'custom'],
                ]
        );

        $this->add_control(
                'unmarked_star_style', [
            'label' => esc_html__('Unmarked Style', CEPE_DOMAIN),
            'type' => Controls_Manager::CHOOSE,
            'label_block' => false,
            'options' => [
                'solid' => [
                    'title' => esc_html__('Solid', CEPE_DOMAIN),
                    'icon' => 'fab fa-star',
                ],
                'outline' => [
                    'title' => esc_html__('Outline', CEPE_DOMAIN),
                    'icon' => 'fab fa-star-o',
                ],
            ],
            'condition' => ['cep_testimonial_type' => 'custom'],
            'default' => 'solid',
                ]
        );

        $this->add_control(
                'title', [
            'label' => esc_html__('Title', CEPE_DOMAIN),
            'type' => Controls_Manager::TEXT,
            'separator' => 'before',
            'condition' => ['cep_testimonial_type' => 'custom'],
                ]
        );

        $this->add_responsive_control(
                'align', [
            'label' => esc_html__('Alignment', CEPE_DOMAIN),
            'type' => Controls_Manager::CHOOSE,
            'options' => [
                'left' => [
                    'title' => esc_html__('Left', CEPE_DOMAIN),
                    'icon' => 'eicon-text-align-left',
                ],
                'center' => [
                    'title' => esc_html__('Center', CEPE_DOMAIN),
                    'icon' => 'eicon-text-align-center',
                ],
                'right' => [
                    'title' => esc_html__('Right', CEPE_DOMAIN),
                    'icon' => 'eicon-text-align-right',
                ],
                'justify' => [
                    'title' => esc_html__('Justified', CEPE_DOMAIN),
                    'icon' => 'eicon-text-align-center',
                ],
            ],
            'prefix_class' => 'elementor-star-rating--align-',
            'selectors' => [
                '{{WRAPPER}}' => 'text-align: {{VALUE}}',
            ],
            'default' => 'center',
                ]
        );

        $this->end_controls_section();


        $this->start_controls_section(
                'section_cept_query', array(
            'label' => esc_html__('Query', CEPE_DOMAIN),
            'condition' => ['cep_testimonial_type' => 'post'],
                )
        );

        $this->add_control(
                'cept_advanced', [
            'label' => esc_html__('Advanced', CEPE_DOMAIN),
            'condition' => ['cep_testimonial_type' => 'post'],
            'type' => Controls_Manager::HEADING,
                ]
        );

        $this->add_control(
                'cept_card_orderby', [
            'label' => esc_html__('Order By', CEPE_DOMAIN),
            'type' => Controls_Manager::SELECT,
            'default' => 'post_date',
            'condition' => ['cep_testimonial_type' => 'post'],
            'options' => [
                'post_date' => esc_html__('Date', CEPE_DOMAIN),
                'post_title' => esc_html__('Title', CEPE_DOMAIN),
                'post_id' => esc_html__('ID', CEPE_DOMAIN),
                'rand' => esc_html__('Random', CEPE_DOMAIN),
            ],
                ]
        );

        $this->add_control(
                'cept_sort_order', [
            'label' => esc_html__('Sort By', CEPE_DOMAIN),
            'type' => Controls_Manager::SELECT,
            'default' => 'desc',
            'condition' => ['cep_testimonial_type' => 'post'],
            'options' => [
                'asc' => esc_html__('ASC', CEPE_DOMAIN),
                'desc' => esc_html__('DESC', CEPE_DOMAIN),
            ],
                ]
        );

        $this->add_control(
                'cept_offset', [
            'label' => esc_html__('Offset', CEPE_DOMAIN),
            'type' => Controls_Manager::NUMBER,
            'default' => 0,
            'condition' => ['cep_testimonial_type' => 'post'],
            'description' => esc_html__('Use this setting to skip over posts (e.g. \'2\' to skip over 2 posts).', CEPE_DOMAIN),
                ]
        );

        $this->end_controls_section();


        /*
         * Start control style tab for testimonial card
         * Start name control style
         */
        $this->start_controls_section(
                'cept_section_design_layout', [
            'label' => esc_html__('Layout', CEPE_DOMAIN),
            'tab' => Controls_Manager::TAB_STYLE,
                ]
        );
        $this->add_control(
                'cept_card_grid_gap', [
            'label' => esc_html__('Grid Gap', CEPE_DOMAIN),
            'type' => Controls_Manager::SLIDER,
            'default' => [
                'size' => 30,
            ],
            'range' => [
                'px' => [
                    'min' => 0,
                    'max' => 100,
                ],
            ],
            'frontend_available' => true,
            'selectors' => [
                '{{WRAPPER}} .cept-card-grid-gap' => 'grid-column-gap: {{SIZE}}{{UNIT}};',
            ],
                ]
        );

        $this->add_control(
                'cept_card_row_gap', [
            'label' => esc_html__('Rows Gap', CEPE_DOMAIN),
            'type' => Controls_Manager::SLIDER,
            'default' => [
                'size' => 30,
            ],
            'range' => [
                'px' => [
                    'min' => 0,
                    'max' => 100,
                ],
            ],
            'frontend_available' => true,
            'selectors' => [
                '{{WRAPPER}} .cept-card-container' => 'margin-bottom: {{SIZE}}{{UNIT}};',
            ],
                ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
                'section_testimonial_name', [
            'label' => esc_html__('Name', CEPE_DOMAIN),
            'tab' => Controls_Manager::TAB_STYLE,
                ]
        );

        $this->add_responsive_control(
                'name_text_align', [
            'label' => esc_html__('Alignment', CEPE_DOMAIN),
            'type' => Controls_Manager::CHOOSE,
            'options' => [
                'left' => [
                    'title' => esc_html__('Left', CEPE_DOMAIN),
                    'icon' => 'eicon-text-align-left',
                ],
                'center' => [
                    'title' => esc_html__('Center', CEPE_DOMAIN),
                    'icon' => 'eicon-text-align-center',
                ],
                'right' => [
                    'title' => esc_html__('Right', CEPE_DOMAIN),
                    'icon' => 'eicon-text-align-center',
                ],
                'justify' => [
                    'title' => esc_html__('Justified', CEPE_DOMAIN),
                    'icon' => 'eicon-text-align-justify',
                ],
            ],
            'default' => 'center',
            'selectors' => [
                '{{WRAPPER}} .elementor-testimonial-name-wrapper,
				 {{WRAPPER}} .testimonial-card-style-6 .name' => 'text-align: {{VALUE}};',
            ],
                ]
        );

        $this->add_control(
                'name_color', [
            'label' => esc_html__('Text Color', CEPE_DOMAIN),
            'type' => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .elementor-testimonial-name-wrapper,
				 {{WRAPPER}} .testimonial-card-style-6 .name' => 'color: {{VALUE}};',
                '{{WRAPPER}} .testimonial-card-style-6 .pic' => 'border: 4px solid {{VALUE}}',
                '{{WRAPPER}} .testimonial-card-style-6 .description' => 'border-bottom: 4px solid {{VALUE}}',
            ],
                ]
        );

        $this->add_group_control(
                Group_Control_Typography::get_type(), [
            'name' => 'typography_name',
            'selector' => '{{WRAPPER}} .elementor-testimonial-name-wrapper,
						   {{WRAPPER}} .testimonial-card-style-6 .name',
                ]
        );

        $this->end_controls_section();

        /*
         * Start position control style
         */
        $this->start_controls_section(
                'section_testimonial_position', [
            'label' => esc_html__('Designation', CEPE_DOMAIN),
            'tab' => Controls_Manager::TAB_STYLE,
                ]
        );

        $this->add_responsive_control(
                'position_text_align', [
            'label' => esc_html__('Alignment', CEPE_DOMAIN),
            'type' => Controls_Manager::CHOOSE,
            'options' => [
                'left' => [
                    'title' => esc_html__('Left', CEPE_DOMAIN),
                    'icon' => 'eicon-text-align-left',
                ],
                'center' => [
                    'title' => esc_html__('Center', CEPE_DOMAIN),
                    'icon' => 'eicon-text-align-center',
                ],
                'right' => [
                    'title' => esc_html__('Right', CEPE_DOMAIN),
                    'icon' => 'eicon-text-align-right',
                ],
                'justify' => [
                    'title' => esc_html__('Justified', CEPE_DOMAIN),
                    'icon' => 'eicon-text-align-justify',
                ],
            ],
            'default' => 'center',
            'selectors' => [
                '{{WRAPPER}} .elementor-testimonial-position-wrapper,
				 {{WRAPPER}} .testimonial-card-style-6 .post' => 'text-align: {{VALUE}};',
            ],
                ]
        );

        $this->add_control(
                'position_color', [
            'label' => esc_html__('Text Color', CEPE_DOMAIN),
            'type' => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .elementor-testimonial-position-wrapper,
				 {{WRAPPER}} .testimonial-card-style-6 .post' => 'color: {{VALUE}};',
                '{{WRAPPER}} .testimonial-card-style-6 .pic,
                 {{WRAPPER}} .testimonial-card-style-6 .description' => 'box-shadow: 0 7px rgba(0, 0, 0, 0.1), 0 5px {{VALUE}}',
            ],
                ]
        );

        $this->add_group_control(
                Group_Control_Typography::get_type(), [
            'name' => 'typography_position',
            'selector' => '{{WRAPPER}} .elementor-testimonial-position-wrapper,
						   {{WRAPPER}} .testimonial-card-style-6 .post',
                ]
        );

        $this->end_controls_section();

        /*
         * Start desription control style
         */
        $this->start_controls_section(
                'section_testimonial_description', [
            'label' => esc_html__('Description', CEPE_DOMAIN),
            'tab' => Controls_Manager::TAB_STYLE,
                ]
        );

        $this->add_responsive_control(
                'description_text_align', [
            'label' => esc_html__('Alignment', CEPE_DOMAIN),
            'type' => Controls_Manager::CHOOSE,
            'options' => [
                'left' => [
                    'title' => esc_html__('Left', CEPE_DOMAIN),
                    'icon' => 'eicon-text-align-left',
                ],
                'center' => [
                    'title' => esc_html__('Center', CEPE_DOMAIN),
                    'icon' => 'eicon-text-align-center',
                ],
                'right' => [
                    'title' => esc_html__('Right', CEPE_DOMAIN),
                    'icon' => 'eicon-text-align-right',
                ],
                'justify' => [
                    'title' => esc_html__('Justified', CEPE_DOMAIN),
                    'icon' => 'eicon-text-align-justify',
                ],
            ],
            'default' => 'center',
            'selectors' => [
                '{{WRAPPER}} .elementor-testimonial-description-wrapper,
				 {{WRAPPER}} .testimonial-card-style-6 .description' => 'text-align: {{VALUE}};',
            ],
                ]
        );

        $this->add_control(
                'description_color', [
            'label' => esc_html__('Text Color', CEPE_DOMAIN),
            'type' => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .elementor-testimonial-description-wrapper,
				 {{WRAPPER}} .testimonial-card-style-6 .description' => 'color: {{VALUE}};',
            ],
                ]
        );

        $this->add_group_control(
                Group_Control_Typography::get_type(), [
            'name' => 'typography_description',
            'selector' => '{{WRAPPER}} .elementor-testimonial-description-wrapper,
						   {{WRAPPER}} .testimonial-card-style-6 .description',
                ]
        );

        $this->end_controls_section();


        /*
         * Start content background control style
         */
        $this->start_controls_section(
                'section_content_background_style', [
            'label' => esc_html__('Content Box Style', CEPE_DOMAIN),
            'tab' => Controls_Manager::TAB_STYLE,
            'condition' => [
                'testimonial_card_style' => ['testimonial-card-style-1', 'testimonial-card-style-3', 'testimonial-card-style-4', 'testimonial-card-style-5'],
            ],
                ]
        );

        $this->add_control(
                'content_background_color', [
            'label' => esc_html__('Background Color', CEPE_DOMAIN),
            'type' => Controls_Manager::COLOR,
            'condition' => [
                'testimonial_card_style' => ['testimonial-card-style-1', 'testimonial-card-style-3', 'testimonial-card-style-4', 'testimonial-card-style-5'],
            ],
            'selectors' => [
                '{{WRAPPER}} .elementor-content-background-color-wrapper' => 'background-color: {{VALUE}};',
                '{{WRAPPER}} .profile-img .dot::before' => 'border-top: 20px solid {{VALUE}};',
                '{{WRAPPER}} .profile-img img' => 'border: 4px solid {{VALUE}};',
            ],
                ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
                'section_title_style', [
            'label' => esc_html__('Title', CEPE_DOMAIN),
            'tab' => Controls_Manager::TAB_STYLE,
            'condition' => [
                'title!' => '',
            ],
                ]
        );

        $this->add_control(
                'title_color', [
            'label' => esc_html__('Text Color', CEPE_DOMAIN),
            'type' => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .elementor-star-rating__title' => 'color: {{VALUE}}',
            ],
                ]
        );

        $this->add_group_control(
                Group_Control_Typography::get_type(), [
            'name' => 'title_typography',
            'selector' => '{{WRAPPER}} .elementor-star-rating__title',
                ]
        );

        $this->add_responsive_control(
                'title_gap', [
            'label' => esc_html__('Gap', CEPE_DOMAIN),
            'type' => Controls_Manager::SLIDER,
            'range' => [
                'px' => [
                    'min' => 0,
                    'max' => 50,
                ],
            ],
            'selectors' => [
                'body:not(.rtl) {{WRAPPER}}:not(.elementor-star-rating--align-justify) .elementor-star-rating__title' => 'margin-right: {{SIZE}}{{UNIT}}',
                'body.rtl {{WRAPPER}}:not(.elementor-star-rating--align-justify) .elementor-star-rating__title' => 'margin-left: {{SIZE}}{{UNIT}}',
            ],
                ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
                'section_stars_style', [
            'label' => esc_html__('Stars', CEPE_DOMAIN),
            'tab' => Controls_Manager::TAB_STYLE,
            'condition' => [
                'testimonial_card_style' => ['testimonial-card-style-1'],
                'testimonial_card_style' => ['testimonial-card-style-2'],
            ]
                ]
        );

        $this->add_responsive_control(
                'icon_size', [
            'label' => esc_html__('Size', CEPE_DOMAIN),
            'type' => Controls_Manager::SLIDER,
            'range' => [
                'px' => [
                    'min' => 0,
                    'max' => 100,
                ],
            ],
            'selectors' => [
                '{{WRAPPER}} .elementor-star-rating' => 'font-size: {{SIZE}}{{UNIT}}',
            ],
                ]
        );

        $this->add_responsive_control(
                'icon_space', [
            'label' => esc_html__('Spacing', CEPE_DOMAIN),
            'type' => Controls_Manager::SLIDER,
            'range' => [
                'px' => [
                    'min' => 0,
                    'max' => 50,
                ],
            ],
            'selectors' => [
                'body:not(.rtl) {{WRAPPER}} .elementor-star-rating i:not(:last-of-type)' => 'margin-right: {{SIZE}}{{UNIT}}',
                'body.rtl {{WRAPPER}} .elementor-star-rating i:not(:last-of-type)' => 'margin-left: {{SIZE}}{{UNIT}}',
            ],
                ]
        );

        $this->add_control(
                'stars_color', [
            'label' => esc_html__('Color', CEPE_DOMAIN),
            'type' => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .elementor-star-rating i:before' => 'color: {{VALUE}}',
            ],
            'separator' => 'before',
                ]
        );

        $this->add_control(
                'stars_unmarked_color', [
            'label' => esc_html__('Unmarked Color', CEPE_DOMAIN),
            'type' => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .elementor-star-rating i' => 'color: {{VALUE}}',
            ],
                ]
        );

        $this->end_controls_section();

        /*
         * End control style tab for testimonial card
         */
    }

    /**
     * @since 1.0.0
     * @access protected
     */
    protected function get_rating() {
        $settings = $this->get_settings_for_display();

        if (isset($settings['cep_testimonial_type']) && $settings['cep_testimonial_type'] == "post") {
            global $post;
            $args = array(
                'post_type' => $settings['cep_testimonial_type_post'],
                'posts_per_page' => $settings['cept_number_of_posts'],
                'post_status' => 'publish',
                'orderby' => $settings['cept_card_orderby'],
                'order' => $settings['cept_sort_order'],
                'offset' => $settings['cept_offset'], // post_offset
            );

            $posts = get_posts($args);
            if (!empty($posts)) {
                foreach ($posts as $data) {
                    $cep_rating = get_post_meta($data->ID, "cep_trating", true);
                    $rating_scale = (int) 5;
                    $rating = (float) $cep_rating > $rating_scale ? $rating_scale : $cep_rating;
                }
            }
        } else if (isset($settings['cep_testimonial_type']) && $settings['cep_testimonial_type'] == "custom") {
            $rating_scale = (int) $settings['rating_scale'];
            $rating = (float) $settings['rating'] > $rating_scale ? $rating_scale : $settings['rating'];
        }

        return [$rating, $rating_scale];
    }

    /**
     * @since 1.0.0
     * @access protected
     */
    protected function render_stars($icon, $rating_star, $rating_of) {
        $rating = $rating_star;
        $floored_rating = $rating;
        $stars_html = '';

        for ($stars = 1; $stars <= $rating_of; $stars++) {
            if ($stars <= $floored_rating) {
                $stars_html .= '<i class="elementor-star-full">' . $icon . '</i>';
            } elseif ($floored_rating + 1 === $stars && $rating !== $floored_rating) {
                $stars_html .= '<i class="elementor-star-' . ( $rating - $floored_rating ) * 10 . '">' . $icon . '</i>';
            } else {
                $stars_html .= '<i class="elementor-star-empty">' . $icon . '</i>';
            }
        }

        return $stars_html;
    }

    /**
     * Render testimonial card widget output on the front-end.
     *
     * Written in PHP and used to generate the final HTML.
     *
     * @access protected
     */
    protected function render() {

        $settings = $this->get_settings_for_display();
        $card_style = $settings['testimonial_card_style'];
        $rating_data = $this->get_rating();
        $textual_rating = $rating_data[0] . '/' . $rating_data[1];
        $icon = '&#61445;';

        if ('star_fontawesome' === $settings['star_style']) {
            if ('outline' === $settings['unmarked_star_style']) {
                $icon = '&#61446;';
            }
        } elseif ('star_unicode' === $settings['star_style']) {
            $icon = '&#9733;';

            if ('outline' === $settings['unmarked_star_style']) {
                $icon = '&#9734;';
            }
        }

        $this->add_render_attribute('icon_wrapper', [
            'class' => 'elementor-star-rating',
            'title' => $textual_rating,
            'itemtype' => 'http://schema.org/Rating',
            'itemscope' => '',
            'itemprop' => 'reviewRating',
        ]);

        $schema_rating = '<span itemprop="ratingValue" class="elementor-screen-only">' . $textual_rating . '</span>';

        if (isset($settings['cep_testimonial_type']) && $settings['cep_testimonial_type'] == "post") {

            global $post;
            $args = array(
                'post_type' => $settings['cep_testimonial_type_post'],
                'posts_per_page' => $settings['cept_number_of_posts'],
                'post_status' => 'publish',
                'orderby' => $settings['cept_card_orderby'],
                'order' => $settings['cept_sort_order'],
                'offset' => $settings['cept_offset'],
            );

            $cpt_datas = get_posts($args);

            if (!empty($cpt_datas)) {
                ?>
                <div class="elementor-grid cept-card-grid-gap <?php echo $card_style; ?>" >
                    <?php
                    foreach ($cpt_datas as $data) {
                        $name = $data->post_title;
                        $position = get_post_meta($data->ID, "cep_tposition", true);
                        $description = $data->post_content;
                        $profile_image = get_the_post_thumbnail_url($data->ID, 'full');
                        $rating = get_post_meta($data->ID, "cep_trating", true);
                        if (!empty($rating) && $rating != "") {
                            $stars_element = '<div ' . $this->get_render_attribute_string('icon_wrapper') . '>' . $this->render_stars($icon, $rating, 5) . ' ' . $schema_rating . '</div>';
                        } else {
                            $stars_element = "";
                        }

                        switch ($card_style) {
                            case 'testimonial-card-style-1':
                                include CEPE_PATH . 'include/testimonial-card/elementor-testimonial-card-1.php';  // Card Style 1
                                break;
                            case 'testimonial-card-style-2':
                                include CEPE_PATH . 'include/testimonial-card/elementor-testimonial-card-2.php';  // Card Style 2
                                break;
                            case 'testimonial-card-style-3':
                                include CEPE_PATH . 'include/testimonial-card/elementor-testimonial-card-3.php';  // Card Style 3
                                break;
                            case 'testimonial-card-style-4':
                                include CEPE_PATH . 'include/testimonial-card/elementor-testimonial-card-4.php';  // Card Style 4
                                break;
                            case 'testimonial-card-style-5':
                                include CEPE_PATH . 'include/testimonial-card/elementor-testimonial-card-5.php';  // Card Style 5
                                break;
                            case 'testimonial-card-style-6':
                                include CEPE_PATH . 'include/testimonial-card/elementor-testimonial-card-6.php';  // Card Style 6
                                break;
                            default:
                                include CEPE_PATH . 'include/testimonial-card/elementor-testimonial-card-1.php';  // Default Card Style 1
                                break;
                        } // End switch case 
                    } wp_reset_postdata();
                    ?>
                </div>            
                <?php
            }
        } else if (isset($settings['cep_testimonial_type']) && $settings['cep_testimonial_type'] == "custom") {

            $stars_element = '<div ' . $this->get_render_attribute_string('icon_wrapper') . '>' . $this->render_stars($icon, $rating_data[0], $rating_data[1]) . ' ' . $schema_rating . '</div>';
            $name = $settings['name'];
            $position = $settings['position'];
            $description = $settings['testimonial_description'];
            $profile_image = $settings['profile_image']['url'];

            switch ($card_style) {
                case 'testimonial-card-style-1':
                    include CEPE_PATH . 'include/testimonial-card/elementor-testimonial-card-1.php';  // Card Style 1
                    break;
                case 'testimonial-card-style-2':
                    include CEPE_PATH . 'include/testimonial-card/elementor-testimonial-card-2.php';  // Card Style 2
                    break;
                case 'testimonial-card-style-3':
                    include CEPE_PATH . 'include/testimonial-card/elementor-testimonial-card-3.php';  // Card Style 3
                    break;
                case 'testimonial-card-style-4':
                    include CEPE_PATH . 'include/testimonial-card/elementor-testimonial-card-4.php';  // Card Style 4
                    break;
                case 'testimonial-card-style-5':
                    include CEPE_PATH . 'include/testimonial-card/elementor-testimonial-card-5.php';  // Card Style 5
                    break;
                case 'testimonial-card-style-6':
                    include CEPE_PATH . 'include/testimonial-card/elementor-testimonial-card-6.php';  // Card Style 6
                    break;
                default:
                    include CEPE_PATH . 'include/testimonial-card/elementor-testimonial-card-1.php';  // Default Card Style 1
                    break;
            } // End switch case 
        }  // End If              
    }

}

Plugin::instance()->widgets_manager->register_widget_type(new Cep_Testimonial_Card_Pro_Elementor_Widget());
