<?php

namespace Elementor;

if (!defined('ABSPATH'))
    exit;      // Exit if accessed directly

class Cep_Tour_Card_Pro_Elementor_Widget extends Widget_Base {

    //Function for get the slug of the element name.
    public function get_name() {
        return 'tour-card-elementor-widget';
    }

    //Function for get the name of the element.
    public function get_title() {
        return __('Tour Card', CEPE_DOMAIN);
    }

    //Function for get the icon of the element.
    public function get_icon() {
        return 'fas fa-bus-alt';
    }

    //Function for include element into the category.
    public function get_categories() {
        return ['card-elements'];
    }

    /*
     * Adding the controls fields for the tour card
     */
    protected function _register_controls() {

        /*
         * Start tour card controls fields
         */
        $this->start_controls_section(
                'section_items_data', array(
            'label' => esc_html__('Tour Card Items', CEPE_DOMAIN),
                )
        );


        $this->add_control(
                'tour_card_style', [
            'label' => __('Tour Card Style', CEPE_DOMAIN),
            'type' => Controls_Manager::SELECT,
            'options' => [
                'tour-card-style-1' => esc_html__('Card Style 1', CEPE_DOMAIN),
                'tour-card-style-2' => esc_html__('Card Style 2', CEPE_DOMAIN),
                'tour-card-style-3' => esc_html__('Card Style 3', CEPE_DOMAIN),
                'tour-card-style-4' => esc_html__('Card Style 4', CEPE_DOMAIN),
                'tour-card-style-5' => esc_html__('Card Style 5', CEPE_DOMAIN),
            ],
            'default' => 'tour-card-style-1',
                ]
        );

        $this->add_control(
                'place_name', [
            'label' => __('Place Name', CEPE_DOMAIN),
            'type' => Controls_Manager::TEXT,
            'default' => __('Name', CEPE_DOMAIN),
            'placeholder' => __('Enter place name', CEPE_DOMAIN),
                ]
        );

        $this->add_control(
                'place_image', [
            'label' => __('Image', CEPE_DOMAIN),
            'type' => Controls_Manager::MEDIA,
            'dynamic' => [
                'active' => true,
            ],
            'default' => [
                'url' => Utils::get_placeholder_image_src(),
            ],
                ]
        );

        $this->add_control(
                'image_background_overlay', [
            'label' => __('Background Overlay', CEPE_DOMAIN),
            'type' => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .tour-card-style-1 .tour-img-overlay,
		{{WRAPPER}} .tour-card-style-2 .tour-main-container,
		{{WRAPPER}} .tour-card-style-3 .tour-img-overlay,
		{{WRAPPER}} .tour-card-style-4 .tour-img-overlay,
		{{WRAPPER}} .tour-card-style-5 .tour-img-overlay' => 'background-color: {{VALUE}};',
            ],
                ]
        );

        $this->add_control(
                'tour_price', array(
            'label' => esc_html__('Cost', CEPE_DOMAIN),
            'type' => Controls_Manager::TEXT,
                )
        );

        $this->add_control(
                'tour_sale', array(
            'label' => esc_html__('Add Sale Tag', CEPE_DOMAIN),
            'type' => Controls_Manager::SWITCHER,
            'default' => 'no',
            'label_on' => __('Show', CEPE_DOMAIN),
            'label_off' => __('Hide', CEPE_DOMAIN),
                )
        );

        $this->add_control(
                'tour_sale_text', array(
            'label' => esc_html__('Add Sale Text', CEPE_DOMAIN),
            'type' => Controls_Manager::TEXT,
            'condition' => [
                'tour_sale' => 'yes',
            ],
                )
        );

        $this->add_control(
                'tour_sale_background', array(
            'label' => esc_html__('Sale Background', CEPE_DOMAIN),
            'type' => Controls_Manager::COLOR,
            'condition' => [
                'tour_sale' => 'yes',
            ],
            'selectors' => [
                '{{WRAPPER}} .tour-card-style-1 .elementor-tour-sale-wrapper,
		{{WRAPPER}} .tour-card-style-2 .elementor-tour-sale-wrapper,
		{{WRAPPER}} .tour-card-style-3 .elementor-tour-sale-wrapper,
		{{WRAPPER}} .tour-card-style-4 .elementor-tour-sale-wrapper,
		{{WRAPPER}} .tour-card-style-5 .elementor-tour-sale-wrapper' => 'background-color: {{VALUE}};',
            ],
                )
        );


        $this->add_responsive_control(
                'tour_sale_alignment', [
            'label' => __('Alignment', CEPE_DOMAIN),
            'type' => Controls_Manager::CHOOSE,
            'options' => [
                'left' => [
                    'title' => __('Left', CEPE_DOMAIN),
                    'icon' => 'eicon-text-align-left',
                ],
                'center' => [
                    'title' => __('Center', CEPE_DOMAIN),
                    'icon' => 'eicon-text-align-center',
                ],
                'right' => [
                    'title' => __('Right', CEPE_DOMAIN),
                    'icon' => 'eicon-text-align-right',
                ],
                'justify' => [
                    'title' => __('Justified', CEPE_DOMAIN),
                    'icon' => 'eicon-text-align-justify',
                ],
            ],
            'condition' => [
                'tour_sale' => 'yes',
            ],
            'selectors' => [
                '{{WRAPPER}} .elementor-tour-sale-wrapper' => 'text-align: {{VALUE}};',
            ],
                ]
        );

        $this->add_control(
                'tour_sale_color', array(
            'label' => esc_html__('Sale Text Color', CEPE_DOMAIN),
            'type' => Controls_Manager::COLOR,
            'condition' => [
                'tour_sale' => 'yes',
            ],
            'selectors' => [
                '{{WRAPPER}} .tour-card-style-1 .elementor-tour-sale-wrapper .tour-sale-text,
		{{WRAPPER}} .tour-card-style-2 .elementor-tour-sale-wrapper .tour-sale-text,
		{{WRAPPER}} .tour-card-style-3 .elementor-tour-sale-wrapper .tour-sale-text,
		{{WRAPPER}} .tour-card-style-4 .elementor-tour-sale-wrapper .tour-sale-text,
		{{WRAPPER}} .tour-card-style-5 .elementor-tour-sale-wrapper .tour-sale-text' => 'color: {{VALUE}};',
            ],
                )
        );


        $this->add_control(
                'tour_sale_border_radius', [
            'label' => __('Border Radius', CEPE_DOMAIN),
            'type' => Controls_Manager::DIMENSIONS,
            'size_units' => ['px', '%'],
            'condition' => [
                'tour_sale' => 'yes',
            ],
            'selectors' => [
                '{{WRAPPER}} .tour-card-style-3 .elementor-tour-sale-wrapper,
		{{WRAPPER}} .tour-card-style-4 .elementor-tour-sale-wrapper,
		{{WRAPPER}} .tour-card-style-5 .elementor-tour-sale-wrapper' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
            ],
                ]
        );

        $this->add_group_control(
                Group_Control_Typography::get_type(), [
            'name' => 'typography_sale',
            'condition' => [
                'tour_sale' => 'yes',
            ],
            'selector' => '{{WRAPPER}} .elementor-tour-sale-wrapper .tour-sale-text',
                ]
        );

        $this->add_control(
                'tour_sale_icon', [
            'label' => 'Sale Icon',
            'type' => \Elementor\Controls_Manager::ICONS,
            'default' => [
                'value' => 'fas fa-tags',
                'library' => 'fa-solid',
            ],
            'condition' => [
                'tour_sale' => 'yes',
            ],
                ]
        );

        $this->add_control(
                'icon_sale_color', [
            'label' => __('Icon Color', CEPE_DOMAIN),
            'type' => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .tour-sale-icon i' => 'color: {{VALUE}};',
            ],
                ]
        );

        $this->add_control(
                'sale_icon_size', [
            'label' => __('Sale Icon Size', CEPE_DOMAIN),
            'type' => Controls_Manager::SLIDER,
            'condition' => [
                'tour_sale' => 'yes',
            ],
            'selectors' => [
                '{{WRAPPER}} .tour-sale-icon i' => 'font-size: {{SIZE}}px;'
            ],
                ]
        );

        $this->add_control(
                'tour_days_icon', [
            'label' => 'Days Icon',
            'type' => \Elementor\Controls_Manager::ICONS,
            'default' => [
                'value' => 'fas fa-sun',
                'library' => 'fa-solid',
            ],
                ]
        );

        $this->add_control(
                'tour_days', array(
            'label' => esc_html__('Days', CEPE_DOMAIN),
            'type' => Controls_Manager::NUMBER,
                )
        );

        $this->add_control(
                'tour_person_icon', [
            'label' => 'Person Icon',
            'type' => \Elementor\Controls_Manager::ICONS,
            'default' => [
                'value' => 'fas fa-users',
                'library' => 'fa-solid',
            ],
                ]
        );


        $this->add_control(
                'tour_person', array(
            'label' => esc_html__('Persons', CEPE_DOMAIN),
            'type' => Controls_Manager::NUMBER,
                )
        );

        $this->add_control(
                'tour_guide_icon', [
            'label' => 'Guide Icon',
            'type' => \Elementor\Controls_Manager::ICONS,
            'default' => [
                'value' => 'fas fa-flag',
                'library' => 'fa-solid',
            ],
                ]
        );

        $this->add_control(
                'tour_guides', array(
            'label' => esc_html__('Guides', CEPE_DOMAIN),
            'type' => Controls_Manager::NUMBER,
            'condition' => [
                'tour_card_style' => ['tour-card-style-1', 'tour-card-style-2', 'tour-card-style-3', 'tour-card-style-4', 'tour-card-style-5'],
            ],
                )
        );

        $this->add_control(
                'display_whatsapp_share', [
            'label' => __('Whatsapp Share', CEPE_DOMAIN),
            'type' => Controls_Manager::SWITCHER,
            'default' => 'yes',
            'label_on' => __('Show', CEPE_DOMAIN),
            'label_off' => __('Hide', CEPE_DOMAIN),
                ]
        );

        $this->add_control(
                'display_tour_description', [
            'label' => __('Display Description', CEPE_DOMAIN),
            'type' => Controls_Manager::SWITCHER,
            'default' => 'yes',
            'label_on' => __('Show', CEPE_DOMAIN),
            'label_off' => __('Hide', CEPE_DOMAIN),
                ]
        );


        $this->add_control(
                'tour_description', array(
            'label' => esc_html__('Description', CEPE_DOMAIN),
            'type' => Controls_Manager::TEXTAREA,
            'condition' => [
                'display_tour_description' => 'yes',
            ],
            'default' => __('Lorem ipsum dolor sit amet, consectetur adipisci ng elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.', CEPE_DOMAIN),
                )
        );

        $this->add_control(
                'button_text', [
            'label' => __('Button Text', CEPE_DOMAIN),
            'type' => Controls_Manager::TEXT,
            'default' => __('Book now', CEPE_DOMAIN),
            'placeholder' => __('Button text', CEPE_DOMAIN),
                ]
        );

        $this->add_control(
                'tour_btn_link', [
            'label' => esc_html__('URL (Link)', CEPE_DOMAIN),
            'type' => \Elementor\Controls_Manager::URL,
            'show_external' => true,
            'default' => [
                'url' => '',
                'is_external' => true,
                'nofollow' => true,
            ],
                ]
        );

        $this->end_controls_section();
        /*
         * End tour card controls fields
         */


        $this->start_controls_section(
                'section_tour_icon', [
            'label' => __('Icon', CEPE_DOMAIN),
            'tab' => Controls_Manager::TAB_STYLE,
                ]
        );

        $this->add_control(
                'tour_detail_icon_color', [
            'label' => __('Color', CEPE_DOMAIN),
            'type' => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .tour-detail-icon' => 'color: {{VALUE}};',
            ],
                ]
        );

        $this->end_controls_section();


        /*
         * Start control style tab for tour card
         * Start name control style
         */
        $this->start_controls_section(
                'section_tour_name', [
            'label' => __('Name', CEPE_DOMAIN),
            'tab' => Controls_Manager::TAB_STYLE,
                ]
        );

        $this->add_responsive_control(
                'name_text_align', [
            'label' => __('Alignment', CEPE_DOMAIN),
            'type' => Controls_Manager::CHOOSE,
            'options' => [
                'left' => [
                    'title' => __('Left', CEPE_DOMAIN),
                    'icon' => 'eicon-text-align-left',
                ],
                'center' => [
                    'title' => __('Center', CEPE_DOMAIN),
                    'icon' => 'eicon-text-align-center',
                ],
                'right' => [
                    'title' => __('Right', CEPE_DOMAIN),
                    'icon' => 'eicon-text-align-right',
                ],
                'justify' => [
                    'title' => __('Justified', CEPE_DOMAIN),
                    'icon' => 'eicon-text-align-justify',
                ],
            ],
            'selectors' => [
                '{{WRAPPER}} .elementor-tour-name-wrapper' => 'text-align: {{VALUE}};',
            ],
                ]
        );

        $this->add_control(
                'name_color', [
            'label' => __('Text Color', CEPE_DOMAIN),
            'type' => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .elementor-tour-name-wrapper' => 'color: {{VALUE}};',
            ],
                ]
        );

        $this->add_group_control(
                Group_Control_Typography::get_type(), [
            'name' => 'typography_name',
            'selector' => '{{WRAPPER}} .elementor-tour-name-wrapper',
                ]
        );

        $this->add_group_control(
                Group_Control_Border::get_type(), [
            'name' => 'border',
            'selector' => '{{WRAPPER}} .tour-card-style-3 .elementor-tour-name-wrapper,
			   {{WRAPPER}} .tour-card-style-4 .elementor-tour-name-wrapper,
			   {{WRAPPER}} .tour-card-style-5 .elementor-tour-name-wrapper,
			   {{WRAPPER}} .tour-card-style-1 .elementor-tour-name-wrapper',
            'separator' => 'before',
                ]
        );

        $this->add_control(
                'tour_button_border_radius', [
            'label' => __('Border Radius', CEPE_DOMAIN),
            'type' => Controls_Manager::DIMENSIONS,
            'size_units' => ['px', '%'],
            'selectors' => [
                '{{WRAPPER}} .tour-card-style-1 .elementor-tour-name-wrapper,
		{{WRAPPER}} .tour-card-style-3 .elementor-tour-name-wrapper,
		{{WRAPPER}} .tour-card-style-4 .elementor-tour-name-wrapper,
		{{WRAPPER}} .tour-card-style-5 .elementor-tour-name-wrapper' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
            ],
                ]
        );

        $this->end_controls_section();

        /*
         * Start position control style
         */
        $this->start_controls_section(
                'section_tour_cost', [
            'label' => __('Cost', CEPE_DOMAIN),
            'tab' => Controls_Manager::TAB_STYLE,
                ]
        );

        $this->add_responsive_control(
                'type_text_align', [
            'label' => __('Alignment', CEPE_DOMAIN),
            'type' => Controls_Manager::CHOOSE,
            'options' => [
                'left' => [
                    'title' => __('Left', CEPE_DOMAIN),
                    'icon' => 'fa fa-align-left',
                ],
                'center' => [
                    'title' => __('Center', CEPE_DOMAIN),
                    'icon' => 'fa fa-align-center',
                ],
                'right' => [
                    'title' => __('Right', CEPE_DOMAIN),
                    'icon' => 'fa fa-align-right',
                ],
                'justify' => [
                    'title' => __('Justified', CEPE_DOMAIN),
                    'icon' => 'fa fa-align-justify',
                ],
            ],
            'selectors' => [
                '{{WRAPPER}} .elementor-tour-price-wrapper' => 'text-align: {{VALUE}};',
            ],
                ]
        );

        $this->add_control(
                'position_color', [
            'label' => __('Text Color', CEPE_DOMAIN),
            'type' => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .elementor-tour-price-wrapper' => 'color: {{VALUE}};',
            ],
                ]
        );

        $this->add_group_control(
                Group_Control_Typography::get_type(), [
            'name' => 'typography_position',
            'selector' => '{{WRAPPER}} .elementor-tour-price-wrapper',
                ]
        );

        $this->add_control(
                'separator_color', [
            'label' => __('Separator Color', CEPE_DOMAIN),
            'type' => Controls_Manager::COLOR,
            'condition' => [
                'tour_card_style' => ['tour-card-style-2'],
            ],
            'selectors' => [
                '{{WRAPPER}} .tour-content' => 'border-bottom-color: {{VALUE}};',
            ],
                ]
        );

        $this->end_controls_section();

        /*
         * Start details control style
         */
        $this->start_controls_section(
                'section_tour_details', [
            'label' => __('Details', CEPE_DOMAIN),
            'tab' => Controls_Manager::TAB_STYLE,
                ]
        );

        $this->add_control(
                'details_text_color', [
            'label' => __('Text Color', CEPE_DOMAIN),
            'type' => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .tour-detail-text' => 'color: {{VALUE}};',
            ],
                ]
        );

        $this->add_group_control(
                Group_Control_Typography::get_type(), [
            'name' => 'typography_detais_text',
            'selector' => '{{WRAPPER}} .tour-detail-text',
                ]
        );

        $this->add_control(
                'details_background_color', [
            'label' => __('Background Color', CEPE_DOMAIN),
            'type' => Controls_Manager::COLOR,
            'condition' => [
                'tour_card_style' => ['tour-card-style-1'],
            ],
            'selectors' => [
                '{{WRAPPER}} .tour-detail-ul' => 'background-color: {{VALUE}};',
            ],
                ]
        );

        $this->end_controls_section();

        /*
         * Start desription control style
         */
        $this->start_controls_section(
                'section_tour_description', [
            'label' => __('Description', CEPE_DOMAIN),
            'tab' => Controls_Manager::TAB_STYLE,
                ]
        );

        $this->add_responsive_control(
                'description_text_align', [
            'label' => __('Alignment', CEPE_DOMAIN),
            'type' => Controls_Manager::CHOOSE,
            'options' => [
                'left' => [
                    'title' => __('Left', CEPE_DOMAIN),
                    'icon' => 'eicon-text-align-left',
                ],
                'center' => [
                    'title' => __('Center', CEPE_DOMAIN),
                    'icon' => 'eicon-text-align-center',
                ],
                'right' => [
                    'title' => __('Right', CEPE_DOMAIN),
                    'icon' => 'eicon-text-align-right',
                ],
                'justify' => [
                    'title' => __('Justified', CEPE_DOMAIN),
                    'icon' => 'eicon-text-align-justify',
                ],
            ],
            'selectors' => [
                '{{WRAPPER}} .elementor-tour-description-wrapper' => 'text-align: {{VALUE}};',
            ],
                ]
        );

        $this->add_control(
                'descriptsion_color', [
            'label' => __('Text Color', CEPE_DOMAIN),
            'type' => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .elementor-tour-description-wrapper' => 'color: {{VALUE}};',
            ],
                ]
        );

        $this->add_group_control(
                Group_Control_Typography::get_type(), [
            'name' => 'typography_description',
            'selector' => '{{WRAPPER}} .elementor-tour-description-wrapper',
                ]
        );

        $this->end_controls_section();

        /*
         * Start button control style
         */
        $this->start_controls_section(
                'section_style', [
            'label' => __('Button', CEPE_DOMAIN),
            'tab' => Controls_Manager::TAB_STYLE,
                ]
        );

        $this->add_responsive_control(
                'button_text_align', [
            'label' => __('Alignment', CEPE_DOMAIN),
            'type' => Controls_Manager::CHOOSE,
            'options' => [
                'left' => [
                    'title' => __('Left', CEPE_DOMAIN),
                    'icon' => 'eicon-text-align-left',
                ],
                'center' => [
                    'title' => __('Center', CEPE_DOMAIN),
                    'icon' => 'eicon-text-align-center',
                ],
                'right' => [
                    'title' => __('Right', CEPE_DOMAIN),
                    'icon' => 'eicon-text-align-right',
                ],
                'justify' => [
                    'title' => __('Justified', CEPE_DOMAIN),
                    'icon' => 'eicon-text-align-justify',
                ],
            ],
            'condition' => [
                'tour_card_style' => ['tour-card-style-2', 'tour-card-style-3', 'tour-card-style-4'],
            ],
            'selectors' => [
                '{{WRAPPER}} .tour-button' => 'text-align: {{VALUE}};',
            ],
                ]
        );

        $this->add_group_control(
                Group_Control_Border::get_type(), [
            'name' => 'btn_border',
            'selector' => '{{WRAPPER}} .tour-button a',
            'separator' => 'before',
                ]
        );

        $this->add_control(
                'tour_btn_border_radius', [
            'label' => __('Border Radius', CEPE_DOMAIN),
            'type' => Controls_Manager::DIMENSIONS,
            'size_units' => ['px', '%'],
            'selectors' => [
                '{{WRAPPER}} .tour-button a' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
            ],
                ]
        );

        $this->add_group_control(
                Group_Control_Typography::get_type(), [
            'name' => 'typography',
            'selector' => '{{WRAPPER}} .tour-button a',
                ]
        );

        $this->start_controls_tabs('tabs_button_style');

        $this->start_controls_tab(
                'tab_button_normal', [
            'label' => __('Normal', CEPE_DOMAIN),
                ]
        );

        $this->add_control(
                'tour_button_text_color', [
            'label' => __('Text Color', CEPE_DOMAIN),
            'type' => Controls_Manager::COLOR,
            'default' => '',
            'selectors' => [
                '{{WRAPPER}} .tour-button a' => 'color: {{VALUE}};',
            ],
                ]
        );

        $this->add_control(
                'background_color', [
            'label' => __('Background Color', CEPE_DOMAIN),
            'type' => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .tour-button a' => 'background-color: {{VALUE}};',
            ],
                ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
                'tab_button_hover', [
            'label' => __('Hover', CEPE_DOMAIN),
                ]
        );

        $this->add_control(
                'tour_text_hover_color', [
            'label' => __('Text Color', CEPE_DOMAIN),
            'type' => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .tour-button a:hover' => 'color: {{VALUE}};',
            ],
                ]
        );

        $this->add_control(
                'tour_button_background_hover_color', [
            'label' => __('Background Color', CEPE_DOMAIN),
            'type' => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .tour-button a:hover' => 'background-color: {{VALUE}};',
            ],
                ]
        );

        $this->add_control(
                'tour_button_hover_border_color', [
            'label' => __('Border Color', CEPE_DOMAIN),
            'type' => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .tour-button a:hover' => 'border-color: {{VALUE}};',
            ],
                ]
        );

        $this->end_controls_tabs();


        $this->add_group_control(
                Group_Control_Box_Shadow::get_type(), [
            'name' => 'button_box_shadow',
            'selector' => '{{WRAPPER}} .tour-button a',
                ]
        );

        $this->add_responsive_control(
                'text_padding', [
            'label' => __('Padding', CEPE_DOMAIN),
            'type' => Controls_Manager::DIMENSIONS,
            'size_units' => ['px', 'em', '%'],
            'selectors' => [
                '{{WRAPPER}} .tour-button a' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
            ],
            'separator' => 'before',
                ]
        );

        $this->end_controls_section();

        /*
         * Start box control style
         */
        $this->start_controls_section(
                'section_tour_contentbox', [
            'label' => __('Box', CEPE_DOMAIN),
            'tab' => Controls_Manager::TAB_STYLE,
                ]
        );

        $this->add_responsive_control(
                'box_padding', [
            'label' => __('Padding', CEPE_DOMAIN),
            'type' => Controls_Manager::DIMENSIONS,
            'size_units' => ['px', '%'],
            'devices' => ['desktop', 'tablet', 'mobile'],
            'selectors' => [
                '{{WRAPPER}} .tour-card-style-1 .tour-container,
		{{WRAPPER}} .tour-card-style-2 .tour-main-container,
		{{WRAPPER}} .tour-card-style-3 .tour-img,
		{{WRAPPER}} .tour-card-style-4 .tour-card-left,
		{{WRAPPER}} .tour-card-style-4 .tour-card-right,
		{{WRAPPER}} .tour-card-style-5 .tour-main-container' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
            ],
                ]
        );

        $this->add_control(
                'button_box_background_color', [
            'label' => __('Background Color', CEPE_DOMAIN),
            'type' => Controls_Manager::COLOR,
            'selectors' => [
                '{{WRAPPER}} .tour-card-style-1 .tour-main-container,
		{{WRAPPER}} .tour-card-style-2 .tour-main-container,
		{{WRAPPER}} .tour-card-style-4 .tour-main-container,
		{{WRAPPER}} .tour-card-style-5 .tour-main-container' => 'background-color: {{VALUE}};',
            ],
                ]
        );

        $this->add_group_control(
                Group_Control_Border::get_type(), [
            'name' => 'image_border',
            'selector' => '{{WRAPPER}} .tour-card-style-1,
                            {{WRAPPER}} .tour-card-style-2,
                            {{WRAPPER}} .tour-card-style-3,
                            {{WRAPPER}} .tour-card-style-4,
                            {{WRAPPER}} .tour-card-style-5',
            'separator' => 'before',
                ]
        );

        $this->add_responsive_control(
                'border_radius', [
            'label' => __('Border Radius', CEPE_DOMAIN),
            'type' => Controls_Manager::DIMENSIONS,
            'size_units' => ['px', '%'],
            'devices' => ['desktop', 'tablet', 'mobile'],
            'selectors' => [
                '{{WRAPPER}} .tour-card-style-1,
		{{WRAPPER}} .tour-card-style-2,
		{{WRAPPER}} .tour-card-style-3,
		{{WRAPPER}} .tour-card-style-4,
		{{WRAPPER}} .tour-card-style-5' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
            ],
                ]
        );

        $this->add_group_control(
                Group_Control_Box_Shadow::get_type(), [
            'name' => 'box_shadow',
            'selector' => '{{WRAPPER}} .tour-card-style-1, {{WRAPPER}} .tour-card-style-2',
                ]
        );
        $this->end_controls_section();

        /*
         * End control style tab for tour card
         */
    }

    /**
     * Render tour card widget output on the frontend.
     *
     * Written in PHP and used to generate the final HTML.
     *
     * @access protected
     */
    protected function render() {

        $settings = $this->get_settings_for_display();

        $tour_btn_link = $settings['tour_btn_link'];
        $target = $settings['tour_btn_link']['is_external'] ? ' target="_blank"' : '';
        $rel = $settings['tour_btn_link']['nofollow'] ? ' rel="nofollow"' : '';

        switch ($settings['tour_card_style']) {
            case 'tour-card-style-1':
                include CEPE_PATH . 'include/tour-card/elementor-tour-card-1.php';  // Card Style 1
                break;
            case 'tour-card-style-2':
                include CEPE_PATH . 'include/tour-card/elementor-tour-card-2.php';  // Card Style 2
                break;
            case 'tour-card-style-3':
                include CEPE_PATH . 'include/tour-card/elementor-tour-card-3.php';  // Card Style 3
                break;
            case 'tour-card-style-4':
                include CEPE_PATH . 'include/tour-card/elementor-tour-card-4.php';  // Card Style 4
                break;
            case 'tour-card-style-5':
                include CEPE_PATH . 'include/tour-card/elementor-tour-card-5.php';  // Card Style 5

                break;
            default:
                include CEPE_PATH . 'include/tour-card/elementor-tour-card-1.php';  // Default Card Style 1
                break;
        }
    }

}

Plugin::instance()->widgets_manager->register_widget_type(new Cep_Tour_Card_Pro_Elementor_Widget());
